@@ -2,7 +2,7 @@
  * mms.c: MMS access plug-in
  *****************************************************************************
  * Copyright (C) 2001, 2002 VideoLAN
- * $Id: mmstu.c,v 1.3 2003/05/09 02:39:21 fenrir Exp $
+ * $Id: mmstu.c,v 1.9 2004/02/12 20:09:38 fenrir Exp $
  *
  * Authors: Laurent Aimar <fenrir@via.ecp.fr>
  *
@@ -77,27 +77,21 @@ int  E_( MMSTUOpen )  ( input_thread_t * );
 void E_( MMSTUClose ) ( input_thread_t * );
 
 
-static ssize_t Read        ( input_thread_t * p_input, byte_t * p_buffer,
-                             size_t i_len );
-static void    Seek        ( input_thread_t *, off_t );
+static ssize_t Read( input_thread_t *, byte_t *, size_t );
+static void    Seek( input_thread_t *, off_t );
 
-static int    MMSOpen( input_thread_t  *, url_t *, int, char * );
-
-static int    MMSStart  ( input_thread_t  *, uint32_t );
-static int    MMSStop  ( input_thread_t  *p_input );
-
-static int    MMSClose  ( input_thread_t  * );
+static int  MMSOpen ( input_thread_t *, url_t *, int );
+static int  MMSStart( input_thread_t *, uint32_t );
+static int  MMSStop ( input_thread_t * );
+static void MMSClose( input_thread_t * );
 
 
-static int     mms_CommandRead( input_thread_t *p_input, int i_command1, int i_command2 );
-static int     mms_CommandSend( input_thread_t *, int, uint32_t, uint32_t, uint8_t *, int );
+static int  mms_CommandRead( input_thread_t *p_input, int i_command1, int i_command2 );
+static int  mms_CommandSend( input_thread_t *, int, uint32_t, uint32_t, uint8_t *, int );
 
-static int     mms_HeaderMediaRead( input_thread_t *, int );
-
-static int     mms_ReceivePacket( input_thread_t * );
-
-//static void mms_ParseURL( url_t *p_url, char *psz_url );
+static int  mms_HeaderMediaRead( input_thread_t *, int );
 
+static int  mms_ReceivePacket( input_thread_t * );
 
 
 /*
@@ -117,12 +111,12 @@ static int     mms_ReceivePacket( input_thread_t * );
  * merde :p.
  */
 
-int  E_( MMSTUOpen )  ( input_thread_t *p_input )
+int  E_(MMSTUOpen)( input_thread_t *p_input )
 {
-    access_sys_t    *p_sys;
-    int         i_proto;
-    char        *psz_network;
-    int         i_status;
+    access_sys_t   *p_sys;
+    int             i_proto;
+    int             i_status;
+    vlc_value_t val;
 
     /* *** allocate p_sys_data *** */
     p_input->p_access_data = p_sys = malloc( sizeof( access_sys_t ) );
@@ -130,28 +124,21 @@ int  E_( MMSTUOpen )  ( input_thread_t *p_input )
 
 
     /* *** Parse URL and get server addr/port and path *** */
-    //mms_ParseURL( &p_sys->url, p_input->psz_name );
     p_sys->p_url = E_( url_new )( p_input->psz_name );
 
     if( *p_sys->p_url->psz_host == '\0' )
     {
         E_( url_free )( p_sys->p_url );
         msg_Err( p_input, "invalid server name" );
-        return( -1 );
+        return VLC_EGENERIC;
     }
     if( p_sys->p_url->i_port <= 0 )
     {
         p_sys->p_url->i_port = 1755;
     }
-#if 0
-    if( p_sys->url.i_bind_port == 0 )
-    {
-        p_sys->url.i_bind_port = 7000;   /* default port */
-    }
-#endif
 
     /* *** connect to this server *** */
-    /* 1: look at  requested protocol (udp/tcp) */
+    /* look at  requested protocol (udp/tcp) */
     i_proto = MMS_PROTO_AUTO;
     if( *p_input->psz_access )
     {
@@ -164,42 +151,28 @@ int  E_( MMSTUOpen )  ( input_thread_t *p_input )
             i_proto = MMS_PROTO_TCP;
         }
     }
-    /* 2: look at ip version ipv4/ipv6 */
-    psz_network = "";
-    if( config_GetInt( p_input, "ipv4" ) )
-    {
-        psz_network = "ipv4";
-    }
-    else if( config_GetInt( p_input, "ipv6" ) )
-    {
-        psz_network = "ipv6";
-    }
-    /* 3: connect */
+
+    /* connect */
     if( i_proto == MMS_PROTO_AUTO )
     {   /* first try with TCP */
-        i_status =
-            MMSOpen( p_input, p_sys->p_url, MMS_PROTO_TCP, psz_network );
-        if( i_status < 0 )
+        if( ( i_status = MMSOpen( p_input, p_sys->p_url, MMS_PROTO_TCP ) ) )
         {   /* then with UDP */
-            i_status =
-             MMSOpen( p_input, p_sys->p_url, MMS_PROTO_UDP, psz_network );
+            i_status = MMSOpen( p_input, p_sys->p_url, MMS_PROTO_UDP );
         }
     }
     else
     {
-
-        i_status =
-            MMSOpen( p_input, p_sys->p_url, i_proto, psz_network );
+        i_status = MMSOpen( p_input, p_sys->p_url, i_proto );
     }
 
-    if( i_status < 0 )
+    if( i_status )
     {
         msg_Err( p_input, "cannot connect to server" );
         E_( url_free )( p_sys->p_url );
-        return( -1 );
+        return VLC_EGENERIC;
     }
-    msg_Dbg( p_input, "connected to %s:%d", p_sys->p_url->psz_host, p_sys->p_url->i_port );
 
+    msg_Dbg( p_input, "connected to %s:%d", p_sys->p_url->psz_host, p_sys->p_url->i_port );
 
     /* *** set exported functions *** */
     p_input->pf_read = Read;
@@ -219,6 +192,10 @@ int  E_( MMSTUOpen )  ( input_thread_t *p_input )
      *  broadcast    yy=0x02, xx= 0x00
      *  pre-recorded yy=0x01, xx= 0x80 if video, 0x00 no video
      */
+    if( p_sys->i_packet_count <= 0 && p_sys->asfh.i_data_packets_count > 0 )
+    {
+        p_sys->i_packet_count = p_sys->asfh.i_data_packets_count;
+    }
     if( p_sys->i_packet_count <= 0 || ( p_sys->i_flags_broadcast >> 24 ) == 0x02 )
     {
         p_input->stream.b_seekable = 0;
@@ -241,19 +218,20 @@ int  E_( MMSTUOpen )  ( input_thread_t *p_input )
         msg_Err( p_input, "cannot start stream" );
         MMSClose( p_input );
         E_( url_free )( p_sys->p_url );
-        return( -1 );
+        return VLC_EGENERIC;
     }
 
     /* Update default_pts to a suitable value for mms access */
-    p_input->i_pts_delay = config_GetInt( p_input, "mms-caching" ) * 1000;
+    var_Get( p_input, "mms-caching", &val );
+    p_input->i_pts_delay = val.i_int * 1000;
 
-    return( 0 );
+    return VLC_SUCCESS;
 }
 
 /*****************************************************************************
  * Close: free unused data structures
  *****************************************************************************/
-void E_( MMSTUClose ) ( input_thread_t *p_input )
+void E_(MMSTUClose)( input_thread_t *p_input )
 {
     access_sys_t    *p_sys = p_input->p_access_data;
 
@@ -356,8 +334,10 @@ static void Seek( input_thread_t * p_input, off_t i_pos )
     vlc_mutex_unlock( &p_input->stream.stream_lock );
 }
 
-static ssize_t Read        ( input_thread_t * p_input, byte_t * p_buffer,
-                             size_t i_len )
+/*****************************************************************************
+ * Read:
+ *****************************************************************************/
+static ssize_t Read( input_thread_t *p_input, byte_t *p_buffer, size_t i_len )
 {
     access_sys_t    *p_sys = p_input->p_access_data;
     size_t      i_data;
@@ -419,16 +399,10 @@ static ssize_t Read        ( input_thread_t * p_input, byte_t * p_buffer,
 /****************************************************************************
  * MMSOpen : Open a connection with the server over mmst or mmsu
  ****************************************************************************/
-static int MMSOpen( input_thread_t  *p_input,
-                    url_t *p_url,
-                    int  i_proto,
-                    char *psz_network ) /* "", "ipv4", "ipv6" */
+static int MMSOpen( input_thread_t  *p_input, url_t *p_url, int  i_proto )
 {
-    module_t    *p_network;
     access_sys_t    *p_sys = p_input->p_access_data;
-
-    network_socket_t    socket_desc;
-    int b_udp = ( i_proto == MMS_PROTO_UDP ) ? 1 : 0;
+    int             b_udp = ( i_proto == MMS_PROTO_UDP ) ? 1 : 0;
 
     var_buffer_t buffer;
     char         tmp[4096];
@@ -444,20 +418,13 @@ static int MMSOpen( input_thread_t  *p_input,
 
     /* *** Open a TCP connection with server *** */
     msg_Dbg( p_input, "waiting for connection..." );
-    socket_desc.i_type = NETWORK_TCP;
-    socket_desc.psz_server_addr = p_url->psz_host;
-    socket_desc.i_server_port   = p_url->i_port;
-    socket_desc.psz_bind_addr   = "";
-    socket_desc.i_bind_port     = 0;
-    p_input->p_private = (void*)&socket_desc;
-    if( !( p_network = module_Need( p_input, "network", psz_network ) ) )
+    p_sys->socket_tcp.i_handle = net_OpenTCP( p_input, p_url->psz_host, p_url->i_port );
+    if( p_sys->socket_tcp.i_handle < 0 )
     {
         msg_Err( p_input, "failed to open a connection (tcp)" );
-        return( -1 );
+        return VLC_EGENERIC;
     }
-    module_Unneed( p_input, p_network );
-    p_sys->socket_tcp.i_handle = socket_desc.i_handle;
-    p_input->i_mtu    = 0; /*socket_desc.i_mtu;*/
+    p_input->i_mtu = 0;
     msg_Dbg( p_input,
              "connection(tcp) with \"%s:%d\" successful",
              p_url->psz_host,
@@ -474,43 +441,21 @@ static int MMSOpen( input_thread_t  *p_input,
         {
 
             msg_Err( p_input, "for udp you have to provide bind address (mms://<server_addr>@<bind_addr/<path> (FIXME)" );
-#if defined( UNDER_CE )
-            CloseHandle( (HANDLE)p_sys->socket_tcp.i_handle );
-#elif defined( WIN32 )
-            closesocket( p_sys->socket_tcp.i_handle );
-#else
-            close( p_sys->socket_tcp.i_handle );
-#endif
-            return( -1 );
+            net_Close( p_sys->socket_tcp.i_handle );
+            return VLC_EGENERIC;
         }
         p_sys->psz_bind_addr = inet_ntoa( name.sin_addr );
 
-        socket_desc.i_type = NETWORK_UDP;
-        socket_desc.psz_server_addr = "";
-        socket_desc.i_server_port   = 0;
-        socket_desc.psz_bind_addr   = p_sys->psz_bind_addr;
-        socket_desc.i_bind_port     = 7000; //p_url->i_bind_port; FIXME
-        p_input->p_private = (void*)&socket_desc;
-        if( !( p_network = module_Need( p_input, "network", psz_network ) ) )
+        p_sys->socket_udp.i_handle = net_OpenUDP( p_input, p_sys->psz_bind_addr, 7000, "", 0 );
+        if( p_sys->socket_udp.i_handle < 0 )
         {
             msg_Err( p_input, "failed to open a connection (udp)" );
-#if defined( UNDER_CE )
-            CloseHandle( (HANDLE)p_sys->socket_tcp.i_handle );
-#elif defined( WIN32 )
-            closesocket( p_sys->socket_tcp.i_handle );
-#else
-            close( p_sys->socket_tcp.i_handle );
-#endif
-            return( -1 );
+            net_Close( p_sys->socket_tcp.i_handle );
+            return VLC_EGENERIC;
         }
-        module_Unneed( p_input, p_network );
-        p_sys->socket_udp.i_handle = socket_desc.i_handle;
-        p_input->i_mtu    = 0;/*socket_desc.i_mtu;  FIXME */
-
         msg_Dbg( p_input,
                  "connection(udp) at \"%s:%d\" successful",
-                 p_sys->psz_bind_addr,
-                 7000 );
+                 p_sys->psz_bind_addr, 7000 );
     }
     else
     {
@@ -562,7 +507,7 @@ static int MMSOpen( input_thread_t  *p_input,
     {
         var_buffer_free( &buffer );
         MMSClose( p_input );
-        return( -1 );
+        return VLC_EGENERIC;
     }
 
     i_server_version = GetDWLE( p_sys->p_cmd + MMS_CMD_HEADERSIZE + 32 );
@@ -629,7 +574,7 @@ static int MMSOpen( input_thread_t  *p_input,
                  "%s protocol selection failed", b_udp ? "UDP" : "TCP" );
         var_buffer_free( &buffer );
         MMSClose( p_input );
-        return( -1 );
+        return VLC_EGENERIC;
     }
     else if( p_sys->i_command != 0x02 )
     {
@@ -658,7 +603,7 @@ static int MMSOpen( input_thread_t  *p_input,
         /*  FIXME */
         var_buffer_free( &buffer );
         MMSClose( p_input );
-        return( -1 );
+        return VLC_EGENERIC;
     }
     if( p_sys->i_command != 0x06 )
     {
@@ -685,7 +630,7 @@ static int MMSOpen( input_thread_t  *p_input,
                  GetDWLE( p_sys->p_cmd + MMS_CMD_HEADERSIZE ) );
         var_buffer_free( &buffer );
         MMSClose( p_input );
-        return( -1 );
+        return VLC_EGENERIC;
     }
 
     p_sys->i_flags_broadcast =
@@ -722,12 +667,15 @@ static int MMSOpen( input_thread_t  *p_input,
     var_buffer_add32( &buffer, 0x00 );
     var_buffer_add32( &buffer, 0x00 );
     var_buffer_add32( &buffer, 0x00 );
-    var_buffer_add64( &buffer, 0x40ac200000000000 );
+    var_buffer_add64( &buffer, (((uint64_t)0x40ac2000)<<32) );
     var_buffer_add32( &buffer, p_sys->i_header_packet_id_type );
+    var_buffer_add32( &buffer, 0x00 );
     mms_CommandSend( p_input, 0x15, p_sys->i_command_level, 0x00,
                      buffer.p_data, buffer.i_data );
 
     /* *** wait for reponse *** */
+    /* Commented out because it fails on some stream (no 0x11 answer) */
+#if 0
     mms_CommandRead( p_input, 0x11, 0 );
 
     if( p_sys->i_command != 0x11 )
@@ -739,6 +687,8 @@ static int MMSOpen( input_thread_t  *p_input,
         MMSClose( p_input );
         return( -1 );
     }
+#endif
+
     /* *** now read header packet *** */
     /* XXX could be split over multiples packets */
     msg_Dbg( p_input, "reading header" );
@@ -749,7 +699,7 @@ static int MMSOpen( input_thread_t  *p_input,
             msg_Err( p_input, "cannot receive header" );
             var_buffer_free( &buffer );
             MMSClose( p_input );
-            return( -1 );
+            return VLC_EGENERIC;
         }
         if( p_sys->i_header >= p_sys->i_header_size )
         {
@@ -827,7 +777,7 @@ static int MMSOpen( input_thread_t  *p_input,
         msg_Err( p_input, "cannot find any stream" );
         var_buffer_free( &buffer );
         MMSClose( p_input );
-        return( -1 );
+        return VLC_EGENERIC;
     }
     mms_CommandSend( p_input, 0x33,
                      i_streams,
@@ -842,7 +792,7 @@ static int MMSOpen( input_thread_t  *p_input,
                  p_sys->i_command );
         var_buffer_free( &buffer );
         MMSClose( p_input );
-        return( -1 );
+        return VLC_EGENERIC;
     }
 
 
@@ -850,13 +800,13 @@ static int MMSOpen( input_thread_t  *p_input,
 
     msg_Info( p_input, "connection sucessful" );
 
-    return( 0 );
+    return VLC_SUCCESS;
 }
 
 /****************************************************************************
  * MMSStart : Start streaming
  ****************************************************************************/
-static int MMSStart  ( input_thread_t  *p_input, uint32_t i_packet )
+static int MMSStart( input_thread_t  *p_input, uint32_t i_packet )
 {
     access_sys_t        *p_sys = p_input->p_access_data;
     var_buffer_t    buffer;
@@ -898,7 +848,7 @@ static int MMSStart  ( input_thread_t  *p_input, uint32_t i_packet )
 /****************************************************************************
  * MMSStop : Stop streaming
  ****************************************************************************/
-static int MMSStop  ( input_thread_t  *p_input )
+static int MMSStop( input_thread_t  *p_input )
 {
     access_sys_t        *p_sys = p_input->p_access_data;
 
@@ -914,7 +864,7 @@ static int MMSStop  ( input_thread_t  *p_input )
 /****************************************************************************
  * MMSClose : Close streaming and connection
  ****************************************************************************/
-static int MMSClose  ( input_thread_t  *p_input )
+static void MMSClose( input_thread_t  *p_input )
 {
     access_sys_t        *p_sys = p_input->p_access_data;
 
@@ -926,24 +876,12 @@ static int MMSClose  ( input_thread_t  *p_input )
                      p_sys->i_command_level,
                      0x00000001,
                      NULL, 0 );
-    /* *** close sockets *** */
-#if defined( UNDER_CE )
-    CloseHandle( (HANDLE)p_sys->socket_tcp.i_handle );
-#elif defined( WIN32 )
-    closesocket( p_sys->socket_tcp.i_handle );
-#else
-    close( p_sys->socket_tcp.i_handle );
-#endif
 
+    /* *** close sockets *** */
+    net_Close( p_sys->socket_tcp.i_handle );
     if( p_sys->i_proto == MMS_PROTO_UDP )
     {
-#if defined( UNDER_CE )
-        CloseHandle( (HANDLE)p_sys->socket_udp.i_handle );
-#elif defined( WIN32 )
-        closesocket( p_sys->socket_udp.i_handle );
-#else
-        close( p_sys->socket_udp.i_handle );
-#endif
+        net_Close( p_sys->socket_udp.i_handle );
     }
 
     FREE( p_sys->p_cmd );
@@ -954,8 +892,6 @@ static int MMSClose  ( input_thread_t  *p_input )
     FREE( p_sys->psz_tool_version );
     FREE( p_sys->psz_update_player_url );
     FREE( p_sys->psz_encryption_type );
-
-    return( 0 );
 }
 
 /****************************************************************************
@@ -963,7 +899,6 @@ static int MMSClose  ( input_thread_t  *p_input )
  * MMS specific functions
  *
  ****************************************************************************/
-
 static int mms_CommandSend( input_thread_t *p_input,
                              int i_command,
                              uint32_t i_prefix1, uint32_t i_prefix2,
@@ -1005,11 +940,11 @@ static int mms_CommandSend( input_thread_t *p_input,
               0 ) == -1 )
     {
         msg_Err( p_input, "failed to send command" );
-        return( -1 );
+        return VLC_EGENERIC;
     }
 
     var_buffer_free( &buffer );
-    return( 0 );
+    return VLC_SUCCESS;
 }
 
 static int  NetFillBuffer( input_thread_t *p_input )
@@ -1179,7 +1114,7 @@ static int  mms_ParseCommand( input_thread_t *p_input,
     {
         msg_Warn( p_input, "truncated command (header incomplete)" );
         p_sys->i_command = 0;
-        return( -1 );
+        return -1;
     }
     i_id =  GetDWLE( p_data + 4 );
     i_length = GetDWLE( p_data + 8 ) + 16;
@@ -1189,7 +1124,7 @@ static int  mms_ParseCommand( input_thread_t *p_input,
         msg_Err( p_input,
                  "incorrect command header (0x%x)", i_id );
         p_sys->i_command = 0;
-        return( -1 );
+        return -1;
     }
 
     if( i_length > p_sys->i_cmd )
@@ -1198,7 +1133,7 @@ static int  mms_ParseCommand( input_thread_t *p_input,
                   "truncated command (missing %d bytes)",
                    i_length - i_data  );
         p_sys->i_command = 0;
-        return( -1 );
+        return -1;
     }
     else if( i_length < p_sys->i_cmd )
     {
@@ -1222,8 +1157,9 @@ static int  mms_ParseCommand( input_thread_t *p_input,
              /* 44: extra */ );
 
     p_sys->i_command = GET32( 36 ) & 0xffff;
+#undef GET32
 
-    return( MMS_PACKET_CMD );
+    return MMS_PACKET_CMD;
 }
 
 static int  mms_ParsePacket( input_thread_t *p_input,
@@ -1242,7 +1178,7 @@ static int  mms_ParsePacket( input_thread_t *p_input,
     if( i_data <= 8 )
     {
         msg_Warn( p_input, "truncated packet (header incomplete)" );
-        return( -1 );
+        return -1;
     }
 
     i_packet_id = p_data[4];
@@ -1257,7 +1193,7 @@ static int  mms_ParsePacket( input_thread_t *p_input,
                  "truncated packet (missing %d bytes)",
                  i_packet_length - i_data  );
         *pi_used = 0;
-        return( -1 );
+        return -1;
     }
     else if( i_packet_length < i_data )
     {
@@ -1275,7 +1211,7 @@ static int  mms_ParsePacket( input_thread_t *p_input,
         i_packet_id != p_sys->i_media_packet_id_type )
     {
         msg_Warn( p_input, "incorrect Packet Id Type (0x%x)", i_packet_id );
-        return( -1 );
+        return -1;
     }
 
     /* we now have a media or a header packet */
@@ -1315,7 +1251,7 @@ static int  mms_ParsePacket( input_thread_t *p_input,
                  "receive header packet (%d bytes)",
                  i_packet_length - 8 ); */
 
-        return( MMS_PACKET_HEADER );
+        return MMS_PACKET_HEADER;
     }
     else
     {
@@ -1327,7 +1263,7 @@ static int  mms_ParsePacket( input_thread_t *p_input,
                  "receive media packet (%d bytes)",
                  i_packet_length - 8 ); */
 
-        return( MMS_PACKET_MEDIA );
+        return MMS_PACKET_MEDIA;
     }
 }
 
@@ -1339,7 +1275,30 @@ static int mms_ReceivePacket( input_thread_t *p_input )
 
     for( ;; )
     {
-        if( NetFillBuffer( p_input ) < 0 )
+        vlc_bool_t b_refill = VLC_TRUE;
+
+        /* first if we need to refill buffer */
+        if( p_sys->i_buffer_tcp >= MMS_CMD_HEADERSIZE )
+        {
+            if( GetDWLE( p_sys->buffer_tcp + 4 ) == 0xb00bface  )
+            {
+                if( GetDWLE( p_sys->buffer_tcp + 8 ) + 16 <= p_sys->i_buffer_tcp )
+                {
+                    b_refill = VLC_FALSE;
+                }
+            }
+            else if( GetWLE( p_sys->buffer_tcp + 6 ) <= p_sys->i_buffer_tcp )
+            {
+                b_refill = VLC_FALSE;
+            }
+        }
+        if( p_sys->i_proto == MMS_PROTO_UDP && p_sys->i_buffer_udp >= 8 &&
+            GetWLE( p_sys->buffer_udp + 6 ) <= p_sys->i_buffer_udp )
+        {
+            b_refill = VLC_FALSE;
+        }
+
+        if( b_refill && NetFillBuffer( p_input ) < 0 )
         {
             msg_Warn( p_input, "cannot fill buffer" );
             continue;
@@ -1411,7 +1370,6 @@ static int mms_ReceivePacket( input_thread_t *p_input )
         {
             return( i_packet_udp_type );
         }
-
     }
 }
 
@@ -1445,7 +1403,7 @@ static int  mms_ReceiveCommand( input_thread_t *p_input )
 
             if( i_status < 0 )
             {
-                return( -1 );
+                return VLC_EGENERIC;
             }
 
             if( p_sys->i_command == 0x1b )
@@ -1459,11 +1417,11 @@ static int  mms_ReceiveCommand( input_thread_t *p_input )
         }
         else
         {
-            return( -1 );
+            return VLC_EGENERIC;
         }
     }
 
-    return( 0 );
+    return VLC_SUCCESS;
 }
 
 #define MMS_RETRY_MAX       10
@@ -1477,7 +1435,6 @@ static int mms_CommandRead( input_thread_t *p_input, int i_command1, int i_comma
 
     for( i_count = 0; i_count < MMS_RETRY_MAX; )
     {
-
         i_status = mms_ReceiveCommand( p_input );
         if( i_status < 0 || p_sys->i_command == 0 )
         {
@@ -1486,11 +1443,11 @@ static int mms_CommandRead( input_thread_t *p_input, int i_command1, int i_comma
         }
         else if( i_command1 == 0 && i_command2 == 0)
         {
-            return( 0 );
+            return VLC_SUCCESS;
         }
         else if( p_sys->i_command == i_command1 || p_sys->i_command == i_command2 )
         {
-            return( 0 );
+            return VLC_SUCCESS;
         }
         else
         {
@@ -1499,11 +1456,11 @@ static int mms_CommandRead( input_thread_t *p_input, int i_command1, int i_comma
                 case 0x03:
                     msg_Warn( p_input, "socket closed by server" );
                     p_sys->i_eos = 1;
-                    return( -1 );
+                    return VLC_EGENERIC;
                 case 0x1e:
                     msg_Warn( p_input, "end of media stream" );
                     p_sys->i_eos = 1;
-                    return( -1 );
+                    return VLC_EGENERIC;
                 default:
                     break;
             }
@@ -1511,7 +1468,7 @@ static int mms_CommandRead( input_thread_t *p_input, int i_command1, int i_comma
     }
     msg_Warn( p_input, "failed to receive command (abording)" );
 
-    return( -1 );
+    return VLC_EGENERIC;
 }
 
 
@@ -1534,7 +1491,7 @@ static int mms_HeaderMediaRead( input_thread_t *p_input, int i_type )
         }
         else if( i_status == i_type || i_type == MMS_PACKET_ANY )
         {
-            return( i_type );
+            return i_type;
         }
         else if( i_status == MMS_PACKET_CMD )
         {
@@ -1543,11 +1500,11 @@ static int mms_HeaderMediaRead( input_thread_t *p_input, int i_type )
                 case 0x03:
                     msg_Warn( p_input, "socket closed by server" );
                     p_sys->i_eos = 1;
-                    return( -1 );
+                    return -1;
                 case 0x1e:
                     msg_Warn( p_input, "end of media stream" );
                     p_sys->i_eos = 1;
-                    return( -1 );
+                    return -1;
                 case 0x20:
                     /* XXX not too dificult to be done EXCEPT that we
                      * need to restart demuxer... and I don't see how we
@@ -1555,7 +1512,7 @@ static int mms_HeaderMediaRead( input_thread_t *p_input, int i_type )
                     msg_Err( p_input,
                              "reinitialization needed --> unsupported" );
                     p_sys->i_eos = 1;
-                    return( -1 );
+                    return -1;
                 default:
                     break;
             }
@@ -1564,6 +1521,6 @@ static int mms_HeaderMediaRead( input_thread_t *p_input, int i_type )
     msg_Err( p_input,
              "cannot receive %s (abording)",
                ( i_type == MMS_PACKET_HEADER ) ? "header" : "media data" );
-    return( -1 );
+    return -1;
 }
 
