@@ -2,7 +2,7 @@
  * file.c
  *****************************************************************************
  * Copyright (C) 2001, 2002 VideoLAN
- * $Id: file.c,v 1.8 2003/06/21 14:24:30 gbazin Exp $
+ * $Id: file.c,v 1.11 2004/01/23 17:56:14 gbazin Exp $
  *
  * Authors: Laurent Aimar <fenrir@via.ecp.fr>
  *          Eric Petit <titer@videolan.org>
@@ -49,6 +49,9 @@
 #ifndef S_IROTH
 #   define S_IROTH 0
 #endif
+#ifndef STDOUT_FILENO
+#   define STDOUT_FILENO 1
+#endif
 
 /*****************************************************************************
  * Exported prototypes
@@ -58,6 +61,7 @@ static void    Close  ( vlc_object_t * );
 
 static int     Write( sout_access_out_t *, sout_buffer_t * );
 static int     Seek ( sout_access_out_t *, off_t  );
+static int     Read ( sout_access_out_t *, sout_buffer_t * );
 
 /*****************************************************************************
  * Module descriptor
@@ -81,6 +85,7 @@ struct sout_access_out_sys_t
 static int Open( vlc_object_t *p_this )
 {
     sout_access_out_t   *p_access = (sout_access_out_t*)p_this;
+    int                 i_flags;
 
     if( !( p_access->p_sys = malloc( sizeof( sout_access_out_sys_t ) ) ) )
     {
@@ -93,13 +98,22 @@ static int Open( vlc_object_t *p_this )
         msg_Err( p_access, "no file name specified" );
         return VLC_EGENERIC;
     }
+    i_flags = O_RDWR|O_CREAT;
+    if( sout_cfg_find_value( p_access->p_cfg, "append" ) )
+    {
+        i_flags |= O_APPEND;
+    }
+    else
+    {
+        i_flags |= O_TRUNC;
+    }
     if( !strcmp( p_access->psz_name, "-" ) )
     {
         p_access->p_sys->i_handle = STDOUT_FILENO;
         msg_Dbg( p_access, "using stdout" );
     }
     else if( ( p_access->p_sys->i_handle =
-               open( p_access->psz_name, O_WRONLY|O_CREAT|O_TRUNC,
+               open( p_access->psz_name, i_flags,
                      S_IWRITE | S_IREAD | S_IRGRP | S_IROTH ) ) == -1 )
     {
         msg_Err( p_access, "cannot open `%s'", p_access->psz_name );
@@ -107,8 +121,9 @@ static int Open( vlc_object_t *p_this )
         return( VLC_EGENERIC );
     }
 
-    p_access->pf_write        = Write;
-    p_access->pf_seek         = Seek;
+    p_access->pf_write = Write;
+    p_access->pf_read  = Read;
+    p_access->pf_seek  = Seek;
 
     msg_Info( p_access, "Open: name:`%s'", p_access->psz_name );
     return VLC_SUCCESS;
@@ -119,7 +134,7 @@ static int Open( vlc_object_t *p_this )
  *****************************************************************************/
 static void Close( vlc_object_t * p_this )
 {
-    sout_access_out_t   *p_access = (sout_access_out_t*)p_this;
+    sout_access_out_t *p_access = (sout_access_out_t*)p_this;
 
     if( strcmp( p_access->psz_name, "-" ) )
     {
@@ -136,6 +151,23 @@ static void Close( vlc_object_t * p_this )
 /*****************************************************************************
  * Read: standard read on a file descriptor.
  *****************************************************************************/
+static int Read( sout_access_out_t *p_access, sout_buffer_t *p_buffer )
+{
+    if( strcmp( p_access->psz_name, "-" ) )
+    {
+        return read( p_access->p_sys->i_handle, p_buffer->p_buffer,
+                     p_buffer->i_size );
+    }
+    else
+    {
+        msg_Err( p_access, "cannot seek while using stdout" );
+        return VLC_EGENERIC;
+    }
+}
+
+/*****************************************************************************
+ * Write: standard write on a file descriptor.
+ *****************************************************************************/
 static int Write( sout_access_out_t *p_access, sout_buffer_t *p_buffer )
 {
     size_t i_write = 0;
@@ -160,7 +192,7 @@ static int Write( sout_access_out_t *p_access, sout_buffer_t *p_buffer )
  *****************************************************************************/
 static int Seek( sout_access_out_t *p_access, off_t i_pos )
 {
-    msg_Dbg( p_access, "Seek: pos:"I64Fd, (int64_t)i_pos );
+    //msg_Dbg( p_access, "Seek: pos:"I64Fd, (int64_t)i_pos );
 
     if( strcmp( p_access->psz_name, "-" ) )
     {
