@@ -2,7 +2,7 @@
  * vorbis.c: vorbis decoder/encoder/packetizer module making use of libvorbis.
  *****************************************************************************
  * Copyright (C) 2001-2003 VideoLAN
- * $Id: vorbis.c,v 1.28 2003/12/22 02:24:51 sam Exp $
+ * $Id: vorbis.c,v 1.32 2004/02/22 15:57:41 fenrir Exp $
  *
  * Authors: Gildas Bazin <gbazin@netcourrier.com>
  *
@@ -26,6 +26,8 @@
  *****************************************************************************/
 #include <vlc/vlc.h>
 #include <vlc/decoder.h>
+#include <vlc/input.h>
+#include "vlc_playlist.h"
 
 #include <ogg/ogg.h>
 
@@ -248,8 +250,8 @@ static void *DecodeBlock( decoder_t *p_dec, block_t **pp_block )
         if( vorbis_synthesis_headerin( &p_sys->vi, &p_sys->vc,
                                        &oggpacket ) < 0 )
         {
-            msg_Err( p_dec, "This bitstream does not contain Vorbis "
-                     "audio data");
+            msg_Err( p_dec, "this bitstream does not contain Vorbis "
+                     "audio data.");
             block_Release( *pp_block );
             return NULL;
         }
@@ -453,6 +455,9 @@ static void ParseVorbisComments( decoder_t *p_dec )
     input_thread_t *p_input = (input_thread_t *)p_dec->p_parent;
     input_info_category_t *p_cat =
         input_InfoCategory( p_input, _("Vorbis comment") );
+    playlist_t *p_playlist = vlc_object_find( p_dec, VLC_OBJECT_PLAYLIST,
+                                              FIND_ANYWHERE );
+    playlist_item_t *p_item;
     int i = 0;
     char *psz_name, *psz_value, *psz_comment;
     while ( i < p_dec->p_sys->vc.comments )
@@ -460,7 +465,7 @@ static void ParseVorbisComments( decoder_t *p_dec )
         psz_comment = strdup( p_dec->p_sys->vc.user_comments[i] );
         if( !psz_comment )
         {
-            msg_Warn( p_dec, "Out of memory" );
+            msg_Warn( p_dec, "out of memory" );
             break;
         }
         psz_name = psz_comment;
@@ -470,10 +475,23 @@ static void ParseVorbisComments( decoder_t *p_dec )
             *psz_value = '\0';
             psz_value++;
             input_AddInfo( p_cat, psz_name, psz_value );
+            vlc_mutex_lock( &p_playlist->object_lock );
+            p_item = playlist_ItemGetByPos( p_playlist, -1 );
+            vlc_mutex_unlock( &p_playlist->object_lock );
+            if( !p_item)
+            {
+                    msg_Err(p_dec, "unable to find item" );
+                    return;
+            }
+            vlc_mutex_lock( &p_item->lock );
+            playlist_ItemAddInfo( p_item, _("Vorbis comment") ,
+                            psz_name, psz_value );
+            vlc_mutex_unlock( &p_item->lock );
         }
         free( psz_comment );
         i++;
     }
+    if( p_playlist ) vlc_object_release( p_playlist );
 }
 
 /*****************************************************************************
