@@ -1,8 +1,8 @@
 /*****************************************************************************
  * libmp4.h : LibMP4 library for mp4 module for vlc
  *****************************************************************************
- * Copyright (C) 2001 VideoLAN
- * $Id: libmp4.h,v 1.17 2003/10/07 14:59:10 gbazin Exp $
+ * Copyright (C) 2001-2004 VideoLAN
+ * $Id: libmp4.h,v 1.20 2004/01/25 20:05:28 hartman Exp $
  * Authors: Laurent Aimar <fenrir@via.ecp.fr>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -154,6 +154,15 @@
 #define FOURCC_gmhd VLC_FOURCC( 'g', 'm', 'h', 'd' )
 #define FOURCC_wave VLC_FOURCC( 'w', 'a', 'v', 'e' )
 
+#define FOURCC_drms VLC_FOURCC( 'd', 'r', 'm', 's' )
+#define FOURCC_sinf VLC_FOURCC( 's', 'i', 'n', 'f' )
+#define FOURCC_schi VLC_FOURCC( 's', 'c', 'h', 'i' )
+#define FOURCC_user VLC_FOURCC( 'u', 's', 'e', 'r' )
+#define FOURCC_key  VLC_FOURCC( 'k', 'e', 'y', ' ' )
+#define FOURCC_iviv VLC_FOURCC( 'i', 'v', 'i', 'v' )
+#define FOURCC_name VLC_FOURCC( 'n', 'a', 'm', 'e' )
+#define FOURCC_priv VLC_FOURCC( 'p', 'r', 'i', 'v' )
+
 /* Do you want some debug information on all read boxes ? */
 #define MP4_VERBOSE  1
 
@@ -381,6 +390,8 @@ typedef struct MP4_Box_data_sample_soun_s
     int     i_qt_description;
     uint8_t *p_qt_description;
 
+    void    *p_drms;
+
 } MP4_Box_data_sample_soun_t;
 
 typedef struct MP4_Box_data_sample_vide_s
