@@ -1,11 +1,11 @@
 /*****************************************************************************
- * prefs.m: MacOS X plugin for vlc
+ * prefs.m: MacOS X module for vlc
  *****************************************************************************
- * Copyright (C) 2002-2003 VideoLAN
- * $Id: prefs.m,v 1.33 2003/08/08 16:41:04 massiot Exp $
+ * Copyright (C) 2002-2004 VideoLAN
+ * $Id: prefs.m,v 1.41 2004/02/19 19:38:58 hartman Exp $
  *
- * Authors:	Jon Lech Johansen <jon-vl@nanocrew.net>
- *		Derk-Jan Hartman <thedj at users.sf.net>
+ * Authors: Jon Lech Johansen <jon-vl@nanocrew.net>
+ *          Derk-Jan Hartman <hartman at videolan dot org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -31,6 +31,7 @@
 
 #include "intf.h"
 #include "prefs.h"
+#include "vlc_keys.h"
 
 /*****************************************************************************
  * VLCPrefs implementation
@@ -128,9 +129,7 @@
         case CONFIG_ITEM_DIRECTORY:
             {
                 char *psz_value;
-                NSString *o_value;
-    
-                o_value = [o_vlc_config stringValue];
+                NSString *o_value = [o_vlc_config stringValue];
                 psz_value = (char *)[o_value UTF8String];
     
                 config_PutPsz( p_intf, psz_name, psz_value );
@@ -153,7 +152,43 @@
                 config_PutFloat( p_intf, psz_name, f_value );
             }
             break;
-    
+
+        case CONFIG_ITEM_KEY:
+            {
+                unsigned int i_key = config_GetInt( p_intf, psz_name );
+                unsigned int i_new_key = 0;
+
+                if( [o_vlc_config class] == [VLCMatrix class] )
+                {
+                    int i;
+                    NSButtonCell *o_current_cell;
+                    NSArray *o_cells = [o_vlc_config cells];
+                    i_new_key = (i_key & ~KEY_MODIFIER);
+                    for( i = 0; i < [o_cells count]; i++ )
+                    {
+                        o_current_cell = [o_cells objectAtIndex:i];
+                        if( [[o_current_cell title] isEqualToString:_NS("Command")] && 
+                            [o_current_cell state] == NSOnState )
+                                i_new_key |= KEY_MODIFIER_COMMAND;
+                        if( [[o_current_cell title] isEqualToString:_NS("Control")] && 
+                            [o_current_cell state] == NSOnState )
+                                i_new_key |= KEY_MODIFIER_CTRL;
+                        if( [[o_current_cell title] isEqualToString:_NS("Option/Alt")] && 
+                            [o_current_cell state] == NSOnState )
+                                i_new_key |= KEY_MODIFIER_ALT;
+                        if( [[o_current_cell title] isEqualToString:_NS("Shift")] && 
+                            [o_current_cell state] == NSOnState )
+                                i_new_key |= KEY_MODIFIER_SHIFT;
+                    }
+                }
+                else
+                {
+                    i_new_key = (i_key & KEY_MODIFIER);
+                    i_new_key |= StringToKey([[o_vlc_config stringValue] cString]);
+                }
+                config_PutInt( p_intf, psz_name, i_new_key );
+            }
+            break;
         }
     }
     config_SaveConfigFile( p_intf, NULL );
@@ -169,7 +204,7 @@
 {
     NSBeginInformationalAlertSheet(_NS("Reset Preferences"), _NS("Cancel"), _NS("Continue"), 
         nil, o_prefs_window, self, @selector(sheetDidEnd: returnCode: contextInfo:), NULL, nil,
-        _NS("Beware this will reset your VLC Media Player config file.\n"
+        _NS("Beware this will reset your VLC media player preferences.\n"
             "Are you sure you want to continue?") );
 }
 
@@ -351,7 +386,7 @@
     [o_view setAutoresizingMask: NSViewWidthSizable];
     s_rc.origin.x = X_ORIGIN;
     s_rc.origin.y = Y_ORIGIN;
-    BOOL b_right_cat = FALSE;
+    BOOL b_right_cat = TRUE;
 
     if( p_item ) do
     {
@@ -516,7 +551,7 @@
                     if ( p_item->psz_longtext != NULL )
                         psz_duptip = strdup( p_item->psz_longtext );
     
-                    s_rc.size.height = 27;
+                    s_rc.size.height = 25;
                     s_rc.size.width = 200;
                     s_rc.origin.y += 10;
     
@@ -528,6 +563,10 @@
                     [o_combo_box setTarget: self];
                     [o_combo_box setAction: @selector(configChanged:)];
                     [o_combo_box sendActionOn:NSLeftMouseUpMask];
+                    [[NSNotificationCenter defaultCenter] addObserver: self
+                        selector: @selector(configChanged:)
+                        name: NSControlTextDidChangeNotification
+                        object: o_combo_box];
 
                     if ( psz_duptip != NULL )
                     {
@@ -675,6 +714,101 @@
                 s_rc.origin.y += s_rc.size.height;
             }
             break;
+
+            case CONFIG_ITEM_KEY:
+            {
+                int i;
+                char *psz_duptip = NULL;
+                VLCComboBox *o_combo_box;
+
+                if ( p_item->psz_longtext != NULL )
+                    psz_duptip = strdup( p_item->psz_longtext );
+
+                s_rc.origin.y += 10;
+                s_rc.size.width = - 10;
+                s_rc.size.height = 20;
+                CHECK_VIEW_HEIGHT;
+                CONTROL_LABEL( p_item->psz_text );
+                s_rc.origin.x = X_ORIGIN;
+                s_rc.origin.y += s_rc.size.height;
+                s_rc.size.width = s_vrc.size.width - X_ORIGIN * 2;
+                CHECK_VIEW_HEIGHT;
+                VLCMatrix *o_matrix = [[VLCMatrix alloc] initWithFrame: s_rc mode: NSHighlightModeMatrix cellClass: [NSButtonCell class] numberOfRows:2 numberOfColumns:2];
+                NSArray *o_cells = [o_matrix cells];
+                for( i=0; i < [o_cells count]; i++ )
+                {
+                    NSButtonCell *o_current_cell = [o_cells objectAtIndex:i];
+                    [o_current_cell setButtonType: NSSwitchButton];
+                    [o_current_cell setControlSize: NSSmallControlSize];
+                    if( psz_duptip != NULL )
+                    {
+                        [o_matrix setToolTip: [NSApp wrapString: [NSApp localizedString: psz_duptip] toWidth: PREFS_WRAP] forCell: o_current_cell];
+                    }
+                    switch( i )
+                    {
+                        case 0:
+                            [o_current_cell setTitle:_NS("Command")];
+                            [o_current_cell setState: p_item->i_value & KEY_MODIFIER_COMMAND];
+                            break;
+                        case 1:
+                            [o_current_cell setTitle:_NS("Control")];
+                            [o_current_cell setState: p_item->i_value & KEY_MODIFIER_CTRL];
+                            break;
+                        case 2:
+                            [o_current_cell setTitle:_NS("Option/Alt")];
+                            [o_current_cell setState: p_item->i_value & KEY_MODIFIER_ALT];
+                            break;
+                        case 3:
+                            [o_current_cell setTitle:_NS("Shift")];
+                            [o_current_cell setState: p_item->i_value & KEY_MODIFIER_SHIFT];
+                            break;
+                    }
+                    [o_current_cell setTarget: self];
+                    [o_current_cell setAction: @selector(configChanged:)];
+                    [o_current_cell sendActionOn:NSLeftMouseUpMask];
+                }
+                CONTROL_CONFIG( o_matrix, o_module_name,
+                                CONFIG_ITEM_KEY, p_item->psz_name );
+                [o_matrix sizeToCells];
+                [o_view addSubview: [o_matrix autorelease]];
+
+                s_rc.origin.x += [o_matrix frame].size.width + 20;
+                s_rc.size.height = 25;
+                s_rc.size.width = 100;
+
+                CHECK_VIEW_HEIGHT;
+
+                o_combo_box = [[VLCComboBox alloc] initWithFrame: s_rc];
+                CONTROL_CONFIG( o_combo_box, o_module_name,
+                                CONFIG_ITEM_KEY, p_item->psz_name );
+                [o_combo_box setTarget: self];
+                [o_combo_box setAction: @selector(configChanged:)];
+                [o_combo_box sendActionOn:NSLeftMouseUpMask];
+                [[NSNotificationCenter defaultCenter] addObserver: self
+                        selector: @selector(configChanged:)
+                        name: NSControlTextDidChangeNotification
+                        object: o_combo_box];
+
+                if ( psz_duptip != NULL )
+                {
+                    [o_combo_box setToolTip: [NSApp wrapString: [NSApp localizedString: psz_duptip] toWidth: PREFS_WRAP]];
+                }
+                [o_view addSubview: [o_combo_box autorelease]];
+                
+                for( i = 0; i < sizeof(vlc_keys) / sizeof(key_descriptor_t); i++ )
+                {
+                    
+                    if( vlc_keys[i].psz_key_string && *vlc_keys[i].psz_key_string )
+                    [o_combo_box addItemWithObjectValue: [NSApp localizedString:vlc_keys[i].psz_key_string]];
+                }
+                
+                [o_combo_box setStringValue: [NSApp localizedString:KeyToString(( ((unsigned int)p_item->i_value) & ~KEY_MODIFIER ))]];
+                
+                s_rc.origin.y += s_rc.size.height;
+                s_rc.origin.x = X_ORIGIN;
+                if( psz_duptip ) free( psz_duptip );
+            }
+            break;
     
             }
     
@@ -758,7 +892,7 @@ static VLCTreeItem *o_root_item = nil;
         module_config_t *p_item;
         int i_index,j;
 
-        /* List the plugins */
+        /* List the modules */
         p_list = vlc_list_find( p_intf, VLC_OBJECT_MODULE, FIND_ANYWHERE );
         if( !p_list ) return nil;
 
@@ -775,7 +909,7 @@ static VLCTreeItem *o_root_item = nil;
             }
             if( p_module == NULL )
             {
-                msg_Err( p_intf, "Could not find the main module in our prefs" );
+                msg_Err( p_intf, "could not find the main module in our preferences" );
                 return nil;
             }
             if( i_index < p_list->i_count )
@@ -802,7 +936,7 @@ static VLCTreeItem *o_root_item = nil;
                 }
                 while( p_item->i_type != CONFIG_HINT_END && p_item++ );
                 
-                /* Add the plugins item */
+                /* Add the modules item */
                 [o_children addObject:[[VLCTreeItem alloc] initWithName: _NS("Modules")
                     ID: 0 parent:self]];
             }
@@ -823,7 +957,7 @@ static VLCTreeItem *o_root_item = nil;
                 if( !strcmp( p_module->psz_object_name, "main" ) )
                     continue;
         
-                /* Exclude empty plugins */
+                /* Exclude empty modules */
                 p_item = p_module->p_config;
                 if( !p_item ) continue;
                 do
@@ -848,7 +982,7 @@ static VLCTreeItem *o_root_item = nil;
                         {
                             o_capability = [NSApp localizedString: p_submodule->psz_capability];
                             BOOL b_found = FALSE;
-                            for( j = 0; j < [o_children count]; j++ )
+                            for( j = 0; j < (int)[o_children count]; j++ )
                             {
                                 if( [[[o_children objectAtIndex:j] getName] isEqualToString: o_capability] )
                                 {
@@ -866,7 +1000,7 @@ static VLCTreeItem *o_root_item = nil;
                 }
 
                 BOOL b_found = FALSE;
-                for( j = 0; j < [o_children count]; j++ )
+                for( j = 0; j < (int)[o_children count]; j++ )
                 {
                     if( [[[o_children objectAtIndex:j] getName] isEqualToString: o_capability] )
                     {
@@ -893,7 +1027,7 @@ static VLCTreeItem *o_root_item = nil;
                 if( !strcmp( p_module->psz_object_name, "main" ) )
                     continue;
         
-                /* Exclude empty plugins */
+                /* Exclude empty modules */
                 p_item = p_module->p_config;
                 if( !p_item ) continue;
                 do
@@ -959,7 +1093,7 @@ static VLCTreeItem *o_root_item = nil;
 
 - (int)numberOfChildren {
     id i_tmp = [self children];
-    return (i_tmp == IsALeafNode) ? (-1) : [i_tmp count];
+    return (i_tmp == IsALeafNode) ? (-1) : (int)[i_tmp count];
 }
 
 - (BOOL)hasPrefs:(NSString *)o_module_name
@@ -1009,3 +1143,4 @@ IMPL_CONTROL_CONFIG(PopUpButton);
 IMPL_CONTROL_CONFIG(ComboBox);
 IMPL_CONTROL_CONFIG(TextField);
 IMPL_CONTROL_CONFIG(Slider);
+IMPL_CONTROL_CONFIG(Matrix);
