@@ -2,7 +2,7 @@
  * pda_callbacks.c : Callbacks for the pda Linux Gtk+ plugin.
  *****************************************************************************
  * Copyright (C) 2000, 2001 VideoLAN
- * $Id: pda_callbacks.c,v 1.23 2003/12/07 18:58:38 jpsaman Exp $
+ * $Id: pda_callbacks.c,v 1.29 2004/02/29 22:59:59 jpsaman Exp $
  *
  * Authors: Jean-Paul Saman <jpsaman@wxs.nl>
  *
@@ -91,6 +91,7 @@ void PlaylistAddItem(GtkWidget *widget, gchar *name, char **ppsz_options, int i_
 {
     intf_thread_t *p_intf = GtkGetIntf( widget );
     playlist_t    *p_playlist;
+    int           i_id , i_pos=0;
     GtkTreeView   *p_tvplaylist = NULL;
 
     p_playlist = (playlist_t *)
@@ -109,7 +110,7 @@ void PlaylistAddItem(GtkWidget *widget, gchar *name, char **ppsz_options, int i_
         GtkTreeIter   p_play_iter;
 
         p_play_model = gtk_tree_view_get_model(p_tvplaylist);
-
+        
         if (p_play_model)
         {
             int i;
@@ -132,8 +133,11 @@ void PlaylistAddItem(GtkWidget *widget, gchar *name, char **ppsz_options, int i_
             else
 #endif
             {
-                playlist_Add( p_playlist, (const char*)name, (const char**)ppsz_options, i_size,
-                              PLAYLIST_APPEND, PLAYLIST_END );
+                i_id = playlist_AddExt( p_playlist, (const char*)name,
+                              (const char*)name,
+                              PLAYLIST_APPEND, PLAYLIST_END,
+                              (mtime_t) 0,
+                              (const char **) ppsz_options, i_pos );
             }
 
             /* Cleanup memory */
@@ -317,7 +321,7 @@ static char *get_file_perms(const struct stat st)
         psz_perm[8]= 'w';
     if (st.st_mode & S_IXOTH)
     {
-        // 'sticky' bit
+        /* 'sticky' bit */
         if (st.st_mode &S_ISVTX)
             psz_perm[9] = 't';
         else
@@ -340,7 +344,7 @@ gboolean onPDADeleteEvent(GtkWidget *widget, GdkEvent *event, gpointer user_data
     vlc_mutex_lock( &p_intf->change_lock );
     p_intf->p_vlc->b_die = VLC_TRUE;
     vlc_mutex_unlock( &p_intf->change_lock );
-    msg_Dbg( p_intf, "about to exit vlc ... signalled" );
+    msg_Dbg( p_intf, "about to exit vlc ... signaled" );
 
     return TRUE;
 }
@@ -420,7 +424,7 @@ void onAbout(GtkButton *button, gpointer user_data)
 {
     intf_thread_t *p_intf = GtkGetIntf( GTK_WIDGET(button) );
 
-    // Toggle notebook
+    /* Toggle notebook */
     if (p_intf->p_sys->p_notebook)
     {
         gtk_widget_show( GTK_WIDGET(p_intf->p_sys->p_notebook) );
@@ -584,17 +588,27 @@ void NetworkBuildMRL(GtkEditable *editable, gpointer user_data)
 
 void onAddNetworkPlaylist(GtkButton *button, gpointer user_data)
 {
-    GtkEntry     *p_mrl = NULL;
-    const gchar  *psz_mrl_name;
+    intf_thread_t  *p_intf = GtkGetIntf( button );
+
+    GtkEntry       *p_mrl = NULL;
+    GtkCheckButton *p_network_transcode = NULL;
+    gboolean        b_network_transcode;
+    const gchar    *psz_mrl_name;
 
     p_mrl = (GtkEntry*) lookup_widget(GTK_WIDGET(button),"entryMRL" );
-    if (p_mrl)
+    psz_mrl_name = gtk_entry_get_text(p_mrl);
+
+    p_network_transcode = (GtkCheckButton*) lookup_widget(GTK_WIDGET(button), "checkNetworkTranscode" );
+    b_network_transcode = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(p_network_transcode));
+    if (b_network_transcode)
     {
-        psz_mrl_name = gtk_entry_get_text(p_mrl);
-        if (psz_mrl_name != NULL)
-        {
-            PlaylistAddItem(GTK_WIDGET(button), (gchar *)psz_mrl_name, 0, 0);
-        }
+        msg_Dbg( p_intf, "Network transcode option selected." );
+        onAddTranscodeToPlaylist(GTK_WIDGET(button), (gchar *)psz_mrl_name);
+    }
+    else
+    {
+        msg_Dbg( p_intf, "Network receiving selected." );
+        PlaylistAddItem(GTK_WIDGET(button), (gchar *)psz_mrl_name, 0, 0);
     }
 }
 
@@ -632,6 +646,9 @@ void onAddCameraToPlaylist(GtkButton *button, gpointer user_data)
     gint            i_v4l_decimation;
     /* end MJPEG only */
 
+    GtkCheckButton  *p_check_v4l_transcode = NULL;
+    gboolean         b_v4l_transcode;
+    
     char **ppsz_options = NULL; /* list of options */
     int  i_options=0;
     char v4l_mrl[6];
@@ -658,7 +675,7 @@ void onAddCameraToPlaylist(GtkButton *button, gpointer user_data)
     }
 
     i_pos = snprintf( &v4l_mrl[0], 6, "v4l");
-    v4l_mrl[5]='\0'; 
+    v4l_mrl[5]='\0';
 
     entryV4LChannel    = (GtkSpinButton*) lookup_widget( GTK_WIDGET(button), "entryV4LChannel" );
     entryV4LFrequency  = (GtkSpinButton*) lookup_widget( GTK_WIDGET(button), "entryV4LFrequency" );
@@ -719,7 +736,18 @@ void onAddCameraToPlaylist(GtkButton *button, gpointer user_data)
     }
     /* end MJPEG only */
 
-    PlaylistAddItem(GTK_WIDGET(button), (gchar*) &v4l_mrl, ppsz_options, i_options);
+    p_check_v4l_transcode = (GtkCheckButton*) lookup_widget(GTK_WIDGET(button), "checkV4LTranscode" );
+    b_v4l_transcode = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(p_check_v4l_transcode));
+    if (b_v4l_transcode)
+    {
+        msg_Dbg( p_intf, "Camera transcode option selected." );
+        onAddTranscodeToPlaylist(GTK_WIDGET(button), (gchar *)v4l_mrl);
+    }
+    else
+    {
+        msg_Dbg( p_intf, "Camera reception option selected." );
+        PlaylistAddItem(GTK_WIDGET(button), (gchar*) &v4l_mrl, ppsz_options, i_options);
+    }
 }
 
 
@@ -811,6 +839,11 @@ void onUpdatePlaylist(GtkButton *button, gpointer user_data)
     vlc_object_release( p_playlist );
 }
 
+void deleteItemFromPlaylist(gpointer data, gpointer user_data)
+{
+    gtk_tree_path_free((GtkTreePath*) data); // removing an item.
+}
+
 void onDeletePlaylist(GtkButton *button, gpointer user_data)
 {
     intf_thread_t *p_intf = GtkGetIntf( button );
@@ -858,7 +891,10 @@ void onDeletePlaylist(GtkButton *button, gpointer user_data)
                     }
                 }
             }
+#if 0 
             g_list_foreach (p_rows, (GFunc*)gtk_tree_path_free, NULL);
+#endif /* Testing the next line */
+            g_list_foreach (p_rows, deleteItemFromPlaylist, NULL);
             g_list_free (p_rows);
         }
 
@@ -1006,6 +1042,11 @@ void onAddTranscodeToPlaylist(GtkButton *button, gpointer user_data)
         }
     }
 
+    /* Update the playlist */
+    playlist_t *p_playlist = (playlist_t *)vlc_object_find( p_intf, VLC_OBJECT_PLAYLIST, FIND_ANYWHERE );
+    if( p_playlist == NULL ) return;
+
+    /* Get all the options. */
     i_pos = snprintf( &mrl[0], VLC_MAX_MRL, "sout");
     mrl[6] = '\0';
     /* option 1 */
@@ -1053,7 +1094,7 @@ void onAddTranscodeToPlaylist(GtkButton *button, gpointer user_data)
 
     /* option 2 */
     i_pos = 0;
-    i_pos = snprintf( &ppsz_options[i_options++][i_pos], VLC_MAX_MRL - i_pos, "dst=" );
+    i_pos = snprintf( &ppsz_options[i_options++][i_pos], VLC_MAX_MRL - i_pos, "#" );
     if (i_pos>=VLC_MAX_MRL) ppsz_options[i_options][VLC_MAX_MRL-1] = '\0';
 
     p_entryStdAccess = (GtkEntry*) lookup_widget( GTK_WIDGET(button), "entryStdAccess" );
@@ -1069,47 +1110,43 @@ void onAddTranscodeToPlaylist(GtkButton *button, gpointer user_data)
     b_sap_announce = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(p_checkSAP));
     b_slp_announce = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(p_checkSLP));
 
-    if ( strncasecmp( (const char*)p_std_access, "display", 7 ) == 0)
+    i_pos += snprintf( &ppsz_options[i_options][i_pos], VLC_MAX_MRL - i_pos, "std{access=%s,", (char*)p_std_access);
+    if (i_pos>=VLC_MAX_MRL) ppsz_options[i_options][VLC_MAX_MRL-1] = '\0';
+    i_pos += snprintf( &ppsz_options[i_options][i_pos], VLC_MAX_MRL - i_pos, "mux=%s,", (char*)p_std_muxer);
+    if (i_pos>=VLC_MAX_MRL) ppsz_options[i_options][VLC_MAX_MRL-1] = '\0';
+    i_pos += snprintf( &ppsz_options[i_options][i_pos], VLC_MAX_MRL - i_pos, "url=%s", (char*)p_std_url);
+    if (i_pos>=VLC_MAX_MRL) ppsz_options[i_options][VLC_MAX_MRL-1] = '\0';
+
+    if (strncasecmp( (const char*)p_std_access, "udp", 3)==0)
     {
-        i_pos += snprintf( &ppsz_options[i_options][i_pos], VLC_MAX_MRL - i_pos, "%s,", (char*)p_std_access);
-        if (i_pos>=VLC_MAX_MRL) ppsz_options[i_options][VLC_MAX_MRL-1] = '\0';
+        if (b_sap_announce)
+        {
+            i_pos += snprintf( &ppsz_options[i_options][i_pos], VLC_MAX_MRL - i_pos, "sap=%s", (char*)p_std_announce);
+            if (i_pos>=VLC_MAX_MRL) ppsz_options[i_options][VLC_MAX_MRL-1] = '\0';
+        }
+        if (b_slp_announce)
+        {
+            i_pos += snprintf( &ppsz_options[i_options][i_pos], VLC_MAX_MRL - i_pos, "slp=%s", (char*)p_std_announce);
+            if (i_pos>=VLC_MAX_MRL) ppsz_options[i_options][VLC_MAX_MRL-1] = '\0';
+        }
+    }
+
+    i_std_ttl = gtk_spin_button_get_value_as_int(p_entryStdTTL);
+
+    i_pos += snprintf( &ppsz_options[i_options++][i_pos], VLC_MAX_MRL - i_pos, "ttl=%d}", (int)i_std_ttl);
+    if (i_pos>=VLC_MAX_MRL) ppsz_options[i_options][VLC_MAX_MRL-1] = '\0';
+
+    if (user_data != NULL)
+    {
+      msg_Dbg(p_intf, "Adding transcoding options to playlist item." );
     }
     else
     {
-        i_pos += snprintf( &ppsz_options[i_options][i_pos], VLC_MAX_MRL - i_pos, "std{access=%s,", (char*)p_std_access);
-        if (i_pos>=VLC_MAX_MRL) ppsz_options[i_options][VLC_MAX_MRL-1] = '\0';
-        i_pos += snprintf( &ppsz_options[i_options][i_pos], VLC_MAX_MRL - i_pos, "mux=%s,", (char*)p_std_muxer);
-        if (i_pos>=VLC_MAX_MRL) ppsz_options[i_options][VLC_MAX_MRL-1] = '\0';
-        i_pos += snprintf( &ppsz_options[i_options][i_pos], VLC_MAX_MRL - i_pos, "url=%s", (char*)p_std_url);
-        if (i_pos>=VLC_MAX_MRL) ppsz_options[i_options][VLC_MAX_MRL-1] = '\0';
-
-        if (strncasecmp( (const char*)p_std_access, "udp", 3)==0)
-        {
-            if (b_sap_announce)
-            {
-                i_pos += snprintf( &ppsz_options[i_options][i_pos], VLC_MAX_MRL - i_pos, "sap=%s", (char*)p_std_announce);
-                if (i_pos>=VLC_MAX_MRL) ppsz_options[i_options][VLC_MAX_MRL-1] = '\0';
-            }
-            if (b_slp_announce)
-            {
-                i_pos += snprintf( &ppsz_options[i_options][i_pos], VLC_MAX_MRL - i_pos, "slp=%s", (char*)p_std_announce);
-                if (i_pos>=VLC_MAX_MRL) ppsz_options[i_options][VLC_MAX_MRL-1] = '\0';
-            }
-        }
-        i_pos += snprintf( &ppsz_options[i_options][i_pos], VLC_MAX_MRL - i_pos, "}");
-        if (i_pos>=VLC_MAX_MRL) ppsz_options[i_options][VLC_MAX_MRL-1] = '\0';
-
-        i_std_ttl = gtk_spin_button_get_value_as_int(p_entryStdTTL);
-
-        i_pos = snprintf( &ppsz_options[i_options++][0], VLC_MAX_MRL, "ttl=%d", (int)i_std_ttl);
-        if (i_pos>=VLC_MAX_MRL) ppsz_options[i_options][VLC_MAX_MRL-1] = '\0';
+      msg_Dbg(p_intf, "Adding --sout to playlist." );
+      PlaylistAddItem(GTK_WIDGET(button), (gchar*) &mrl, ppsz_options, i_options);
     }
-
-    PlaylistAddItem(GTK_WIDGET(button), (gchar*) &mrl, ppsz_options, i_options);
 }
 
-
-
 void onEntryStdAccessChanged(GtkEditable *editable, gpointer user_data)
 {
     intf_thread_t *p_intf = GtkGetIntf( editable );
