@@ -2,7 +2,7 @@
  * mpeg4audio.c: parse and packetize an MPEG 4 audio stream
  *****************************************************************************
  * Copyright (C) 2001, 2002 VideoLAN
- * $Id: mpeg4audio.c,v 1.14 2003/12/22 02:24:53 sam Exp $
+ * $Id: mpeg4audio.c,v 1.17 2004/02/25 18:43:24 gbazin Exp $
  *
  * Authors: Laurent Aimar <fenrir@via.ecp.fr>
  *          Gildas Bazin <gbazin@netcourrier.com>
@@ -151,7 +151,7 @@ static int OpenPacketizer( vlc_object_t *p_this )
     /* Set callback */
     p_dec->pf_packetize = PacketizeBlock;
 
-    msg_Info( p_dec, "Running MPEG4 audio packetizer" );
+    msg_Info( p_dec, "running MPEG4 audio packetizer" );
 
     if( p_dec->fmt_in.i_extra > 0 )
     {
@@ -188,7 +188,7 @@ static int OpenPacketizer( vlc_object_t *p_this )
     }
     else
     {
-        msg_Dbg( p_dec, "No decoder specific info, must be an ADTS stream" );
+        msg_Dbg( p_dec, "no decoder specific info, must be an ADTS stream" );
 
         /* We will try to create a AAC Config from adts */
         p_dec->fmt_out.i_extra = 0;
@@ -253,7 +253,7 @@ static block_t *ADTSPacketizeBlock( decoder_t *p_dec, block_t **pp_block )
         return NULL;
     }
 
-    if( (*pp_block)->b_discontinuity )
+    if( (*pp_block)->i_flags&BLOCK_FLAG_DISCONTINUITY )
     {
         p_sys->i_state = STATE_NOSYNC;
     }
