@@ -2,7 +2,7 @@
  * deinterlace.c : deinterlacer plugin for vlc
  *****************************************************************************
  * Copyright (C) 2000, 2001, 2002, 2003 VideoLAN
- * $Id: deinterlace.c,v 1.18 2003/12/22 14:32:56 sam Exp $
+ * $Id: deinterlace.c,v 1.24 2004/02/13 10:42:24 titer Exp $
  *
  * Author: Sam Hocevar <sam@zoy.org>
  *
@@ -55,7 +55,19 @@ static void RenderMean   ( vout_thread_t *, picture_t *, picture_t * );
 static void RenderBlend  ( vout_thread_t *, picture_t *, picture_t * );
 static void RenderLinear ( vout_thread_t *, picture_t *, picture_t *, int );
 
-static void Merge        ( void *, const void *, const void *, size_t );
+static void MergeGeneric ( void *, const void *, const void *, size_t );
+#if defined(CAN_COMPILE_C_ALTIVEC)
+static void MergeAltivec ( void *, const void *, const void *, size_t );
+#endif
+#if defined(CAN_COMPILE_MMX)
+static void MergeMMX     ( void *, const void *, const void *, size_t );
+#endif
+#if defined(CAN_COMPILE_SSE)
+static void MergeSSE2    ( void *, const void *, const void *, size_t );
+#endif
+#if defined(CAN_COMPILE_MMX) || defined(CAN_COMPILE_SSE)
+static void EndMMX       ( void );
+#endif
 
 static int  SendEvents   ( vlc_object_t *, char const *,
                            vlc_value_t, vlc_value_t, void * );
@@ -76,16 +88,17 @@ static int FilterCallback ( vlc_object_t *, char const *,
 #define MODE_LONGTEXT N_("You can choose the default deinterlace mode")
 
 static char *mode_list[] = { "discard", "blend", "mean", "bob", "linear" };
-static char *mode_list_text[] = { N_("discard"), N_("Blend"), N_("Mean"),
+static char *mode_list_text[] = { N_("Discard"), N_("Blend"), N_("Mean"),
                                   N_("Bob"), N_("Linear") };
 
 vlc_module_begin();
-    add_category_hint( N_("Deinterlace"), NULL, VLC_FALSE );
+    set_description( _("Deinterlacing video filter") );
+    set_capability( "video filter", 0 );
+
     add_string( "deinterlace-mode", "discard", NULL, MODE_TEXT,
                 MODE_LONGTEXT, VLC_FALSE );
         change_string_list( mode_list, mode_list_text, 0 );
-    set_description( _("video deinterlacing filter") );
-    set_capability( "video filter", 0 );
+
     add_shortcut( "deinterlace" );
     set_callbacks( Create, Destroy );
 vlc_module_end();
@@ -107,6 +120,9 @@ struct vout_sys_t
     vout_thread_t *p_vout;
 
     vlc_mutex_t filter_lock;
+
+    void (*pf_merge) ( void *, const void *, const void *, size_t );
+    void (*pf_end_merge) ( void );
 };
 
 /*****************************************************************************
@@ -138,6 +154,35 @@ static int Create( vlc_object_t *p_this )
     p_vout->p_sys->last_date = 0;
     vlc_mutex_init( p_vout, &p_vout->p_sys->filter_lock );
 
+#if defined(CAN_COMPILE_C_ALTIVEC)
+    if( p_vout->p_libvlc->i_cpu & CPU_CAPABILITY_ALTIVEC )
+    {
+        p_vout->p_sys->pf_merge = MergeAltivec;
+        p_vout->p_sys->pf_end_merge = NULL;
+    }
+    else
+#endif
+#if defined(CAN_COMPILE_SSE)
+    if( p_vout->p_libvlc->i_cpu & CPU_CAPABILITY_SSE2 )
+    {
+        p_vout->p_sys->pf_merge = MergeSSE2;
+        p_vout->p_sys->pf_end_merge = EndMMX;
+    }
+    else
+#endif
+#if defined(CAN_COMPILE_MMX)
+    if( p_vout->p_libvlc->i_cpu & CPU_CAPABILITY_MMX )
+    {
+        p_vout->p_sys->pf_merge = MergeMMX;
+        p_vout->p_sys->pf_end_merge = EndMMX;
+    }
+    else
+#endif
+    {
+        p_vout->p_sys->pf_merge = MergeGeneric;
+        p_vout->p_sys->pf_end_merge = NULL;
+    }
+
     /* Look what method was requested */
     var_Create( p_vout, "deinterlace-mode", VLC_VAR_STRING );
     var_Change( p_vout, "deinterlace-mode", VLC_VAR_INHERITVALUE, &val, NULL );
@@ -617,6 +662,9 @@ static void RenderBob( vout_thread_t *p_vout,
     }
 }
 
+#define Merge p_vout->p_sys->pf_merge
+#define EndMerge if(p_vout->p_sys->pf_end_merge) p_vout->p_sys->pf_end_merge
+
 /*****************************************************************************
  * RenderLinear: BOB with linear interpolation
  *****************************************************************************/
@@ -672,6 +720,7 @@ static void RenderLinear( vout_thread_t *p_vout,
                                       p_pic->p[i_plane].i_pitch );
         }
     }
+    EndMerge();
 }
 
 static void RenderMean( vout_thread_t *p_vout,
@@ -700,6 +749,7 @@ static void RenderMean( vout_thread_t *p_vout,
             p_in += 2 * p_pic->p[i_plane].i_pitch;
         }
     }
+    EndMerge();
 }
 
 static void RenderBlend( vout_thread_t *p_vout,
@@ -772,10 +822,13 @@ static void RenderBlend( vout_thread_t *p_vout,
                 break;
         }
     }
+    EndMerge();
 }
 
-static void Merge( void *_p_dest, const void *_p_s1,
-                   const void *_p_s2, size_t i_bytes )
+#undef Merge
+
+static void MergeGeneric( void *_p_dest, const void *_p_s1,
+                          const void *_p_s2, size_t i_bytes )
 {
     uint8_t* p_dest = (uint8_t*)_p_dest;
     const uint8_t *p_s1 = (const uint8_t *)_p_s1;
@@ -802,6 +855,106 @@ static void Merge( void *_p_dest, const void *_p_s1,
     }
 }
 
+#if defined(CAN_COMPILE_MMX)
+static void MergeMMX( void *_p_dest, const void *_p_s1, const void *_p_s2,
+                      size_t i_bytes )
+{
+    uint8_t* p_dest = (uint8_t*)_p_dest;
+    const uint8_t *p_s1 = (const uint8_t *)_p_s1;
+    const uint8_t *p_s2 = (const uint8_t *)_p_s2;
+    uint8_t* p_end = p_dest + i_bytes - 8;
+    while( p_dest < p_end )
+    {
+        __asm__  __volatile__( "movq %2,%%mm1;"
+                               "pavgb %1, %%mm1;"
+                               "movq %%mm1, %0" :"=m" (*p_dest):
+                                                 "m" (*p_s1),
+                                                 "m" (*p_s2) );
+        p_dest += 8;
+        p_s1 += 8;
+        p_s2 += 8;
+    }
+
+    p_end += 8;
+
+    while( p_dest < p_end )
+    {
+        *p_dest++ = ( (uint16_t)(*p_s1++) + (uint16_t)(*p_s2++) ) >> 1;
+    }
+}
+#endif
+
+#if defined(CAN_COMPILE_SSE)
+static void MergeSSE2( void *_p_dest, const void *_p_s1, const void *_p_s2,
+                       size_t i_bytes )
+{
+    uint8_t* p_dest = (uint8_t*)_p_dest;
+    const uint8_t *p_s1 = (const uint8_t *)_p_s1;
+    const uint8_t *p_s2 = (const uint8_t *)_p_s2;
+    uint8_t* p_end = p_dest + i_bytes - 16;
+    while( p_dest < p_end )
+    {
+        __asm__  __volatile__( "movdqu %2,%%xmm1;"
+                               "pavgb %1, %%xmm1;"
+                               "movdqu %%xmm1, %0" :"=m" (*p_dest):
+                                                 "m" (*p_s1),
+                                                 "m" (*p_s2) );
+        p_dest += 16;
+        p_s1 += 16;
+        p_s2 += 16;
+    }
+
+    p_end += 16;
+
+    while( p_dest < p_end )
+    {
+        *p_dest++ = ( (uint16_t)(*p_s1++) + (uint16_t)(*p_s2++) ) >> 1;
+    }
+}
+#endif
+
+#if defined(CAN_COMPILE_MMX) || defined(CAN_COMPILE_SSE)
+static void EndMMX( void )
+{
+    __asm__ __volatile__( "emms" :: );
+}
+#endif
+
+#ifdef CAN_COMPILE_C_ALTIVEC
+static void MergeAltivec( void *_p_dest, const void *_p_s1,
+                          const void *_p_s2, size_t i_bytes )
+{
+    uint8_t *p_dest = (uint8_t*)_p_dest;
+    const uint8_t *p_s1 = (const uint8_t *)_p_s1;
+    const uint8_t *p_s2 = (const uint8_t *)_p_s2;
+    uint8_t *p_end = p_dest + i_bytes - 16;
+
+    if( ( (int)p_s1 & 0xF ) | ( (int)p_s2 & 0xF ) |
+        ( (int)p_dest & 0xF ) )
+    {
+        /* TODO Handle non 16-bytes aligned planes */
+        MergeGeneric( _p_dest, _p_s1, _p_s2, i_bytes );
+        return;
+    }
+
+    while( p_dest < p_end )
+    {
+        vec_st( vec_avg( vec_ld( 0, p_s1 ), vec_ld( 0, p_s2 ) ),
+                0, p_dest );
+        p_s1   += 16;
+        p_s2   += 16;
+        p_dest += 16;
+    }
+
+    p_end += 16;
+
+    while( p_dest < p_end )
+    {
+        *p_dest++ = ( (uint16_t)(*p_s1++) + (uint16_t)(*p_s2++) ) >> 1;
+    }
+}
+#endif
+
 /*****************************************************************************
  * SendEvents: forward mouse and keyboard events to the parent p_vout
  *****************************************************************************/
