@@ -2,7 +2,7 @@
  * vout.c: Windows DirectX video output display method
  *****************************************************************************
  * Copyright (C) 2001-2004 VideoLAN
- * $Id: directx.c,v 1.31 2004/01/02 22:17:57 gbazin Exp $
+ * $Id: directx.c,v 1.36 2004/02/26 13:58:23 gbazin Exp $
  *
  * Authors: Gildas Bazin <gbazin@netcourrier.com>
  *
@@ -96,6 +96,8 @@ static DWORD DirectXFindColorkey( vout_thread_t *p_vout, uint32_t i_color );
 /* Object variables callbacks */
 static int OnTopCallback( vlc_object_t *, char const *,
                           vlc_value_t, vlc_value_t, void * );
+static int FindDevicesCallback( vlc_object_t *, char const *,
+                                vlc_value_t, vlc_value_t, void * );
 
 /*****************************************************************************
  * Module descriptor
@@ -104,22 +106,40 @@ static int OnTopCallback( vlc_object_t *, char const *,
 #define HW_YUV_LONGTEXT N_( \
     "Try to use hardware acceleration for YUV->RGB conversions. " \
     "This option doesn't have any effect when using overlays." )
+
 #define SYSMEM_TEXT N_("Use video buffers in system memory")
 #define SYSMEM_LONGTEXT N_( \
     "Create video buffers in system memory instead of video memory. This " \
     "isn't recommended as usually using video memory allows to benefit from " \
     "more hardware acceleration (like rescaling or YUV->RGB conversions). " \
     "This option doesn't have any effect when using overlays." )
+
 #define TRIPLEBUF_TEXT N_("Use triple buffering for overlays")
 #define TRIPLEBUF_LONGTEXT N_( \
     "Try to use triple bufferring when using YUV overlays. That results in " \
     "much better video quality (no flickering)." )
 
+#define DEVICE_TEXT N_("Name of desired display device")
+#define DEVICE_LONGTEXT N_("In a multimonitor configuration, you can specify "\
+    "the Windows device name of the display that you want the video window " \
+    "to open on. For example, \"\\\\.\\DISPLAY1\" or \"\\\\.\\DISPLAY2\"." )
+
+static char *ppsz_dev[] = { "" };
+static char *ppsz_dev_text[] = { N_("Default") };
+
 vlc_module_begin();
-    add_category_hint( N_("Video"), NULL, VLC_FALSE );
-    add_bool( "directx-hw-yuv", 1, NULL, HW_YUV_TEXT, HW_YUV_LONGTEXT, VLC_TRUE );
-    add_bool( "directx-use-sysmem", 0, NULL, SYSMEM_TEXT, SYSMEM_LONGTEXT, VLC_TRUE );
-    add_bool( "directx-3buffering", 1, NULL, TRIPLEBUF_TEXT, TRIPLEBUF_LONGTEXT, VLC_TRUE );
+    add_bool( "directx-hw-yuv", 1, NULL, HW_YUV_TEXT, HW_YUV_LONGTEXT,
+              VLC_TRUE );
+    add_bool( "directx-use-sysmem", 0, NULL, SYSMEM_TEXT, SYSMEM_LONGTEXT,
+              VLC_TRUE );
+    add_bool( "directx-3buffering", 1, NULL, TRIPLEBUF_TEXT,
+              TRIPLEBUF_LONGTEXT, VLC_TRUE );
+
+    add_string( "directx-device", "", NULL, DEVICE_TEXT, DEVICE_LONGTEXT,
+                VLC_TRUE );
+        change_string_list( ppsz_dev, ppsz_dev_text, FindDevicesCallback );
+        change_action_add( FindDevicesCallback, N_("Refresh list") );
+
     set_description( _("DirectX video output") );
     set_capability( "video output", 100 );
     add_shortcut( "directx" );
@@ -164,9 +184,10 @@ static int OpenVideo( vlc_object_t *p_this )
     p_vout->p_sys->p_display = NULL;
     p_vout->p_sys->p_current_surface = NULL;
     p_vout->p_sys->p_clipper = NULL;
-    p_vout->p_sys->hwnd = NULL;
+    p_vout->p_sys->hwnd = p_vout->p_sys->hvideownd = NULL;
     p_vout->p_sys->hparent = NULL;
     p_vout->p_sys->i_changes = 0;
+    SetRectEmpty( &p_vout->p_sys->rect_display  );
 
     /* Multimonitor stuff */
     p_vout->p_sys->hmonitor = NULL;
@@ -185,6 +206,7 @@ static int OpenVideo( vlc_object_t *p_this )
     var_Create( p_vout, "directx-use-sysmem", VLC_VAR_BOOL|VLC_VAR_DOINHERIT );
     var_Create( p_vout, "directx-hw-yuv", VLC_VAR_BOOL | VLC_VAR_DOINHERIT );
     var_Create( p_vout, "directx-3buffering", VLC_VAR_BOOL|VLC_VAR_DOINHERIT );
+    var_Create( p_vout, "directx-device", VLC_VAR_STRING | VLC_VAR_DOINHERIT );
 
     p_vout->p_sys->b_cursor_hidden = 0;
     p_vout->p_sys->i_lastmoved = mdate();
@@ -242,7 +264,7 @@ static int OpenVideo( vlc_object_t *p_this )
     text.psz_string = _("Always on top");
     var_Change( p_vout, "video-on-top", VLC_VAR_SETTEXT, &text, NULL );
     var_Get( p_vout, "video-on-top", &val );
-    p_vout->p_sys->b_on_top_change = val.b_bool; 
+    p_vout->p_sys->b_on_top_change = val.b_bool;
     var_AddCallback( p_vout, "video-on-top", OnTopCallback, NULL );
 
     return VLC_SUCCESS;
@@ -518,7 +540,7 @@ static int Manage( vout_thread_t *p_vout )
         HMENU hMenu = GetSystemMenu( p_vout->p_sys->hwnd, FALSE );
 
         var_Get( p_vout, "video-on-top", &val );
- 
+
         /* Set the window on top if necessary */
         if( val.b_bool && !( GetWindowLong( p_vout->p_sys->hwnd, GWL_EXSTYLE )
                            & WS_EX_TOPMOST ) )
@@ -563,7 +585,7 @@ static void Display( vout_thread_t *p_vout, picture_t *p_pic )
 
     if( (p_vout->p_sys->p_display == NULL) )
     {
-        msg_Warn( p_vout, "no display!!" );
+        msg_Warn( p_vout, "no display!" );
         return;
     }
 
@@ -633,7 +655,7 @@ static void Display( vout_thread_t *p_vout, picture_t *p_pic )
 /*****************************************************************************
  * DirectXEnumCallback: Device enumeration
  *****************************************************************************
- * This callback function is called by DirectDraw once for each 
+ * This callback function is called by DirectDraw once for each
  * available DirectDraw device.
  *****************************************************************************/
 BOOL WINAPI DirectXEnumCallback( GUID* p_guid, LPTSTR psz_desc,
@@ -641,10 +663,51 @@ BOOL WINAPI DirectXEnumCallback( GUID* p_guid, LPTSTR psz_desc,
                                  HMONITOR hmon )
 {
     vout_thread_t *p_vout = (vout_thread_t *)p_context;
+    vlc_value_t device;
+
     msg_Dbg( p_vout, "DirectXEnumCallback: %s, %s", psz_desc, psz_drivername );
 
-    if( hmon && hmon == p_vout->p_sys->hmonitor )
+    if( hmon )
     {
+        var_Get( p_vout, "directx-device", &device );
+
+        if( ( !device.psz_string || !*device.psz_string ) &&
+            hmon == p_vout->p_sys->hmonitor )
+        {
+            if( device.psz_string ) free( device.psz_string );
+        }
+        else if( strcmp( psz_drivername, device.psz_string ) == 0 )
+        {
+            MONITORINFO monitor_info;
+            monitor_info.cbSize = sizeof( MONITORINFO );
+
+            if( p_vout->p_sys->GetMonitorInfo( hmon, &monitor_info ) )
+            {
+                RECT rect;
+
+                /* Move window to the right screen */
+                GetWindowRect( p_vout->p_sys->hwnd, &rect );
+                if( !IntersectRect( &rect, &rect, &monitor_info.rcWork ) )
+                {
+                    rect.left = monitor_info.rcWork.left;
+                    rect.top = monitor_info.rcWork.top;
+                    msg_Dbg( p_vout, "DirectXEnumCallback: Setting window "
+                             "position to %d,%d", rect.left, rect.top );
+                    SetWindowPos( p_vout->p_sys->hwnd, NULL,
+                                  rect.left, rect.top, 0, 0,
+                                  SWP_NOSIZE | SWP_NOZORDER | SWP_NOACTIVATE );
+                }
+            }
+
+            p_vout->p_sys->hmonitor = hmon;
+            if( device.psz_string ) free( device.psz_string );
+        }
+        else
+        {
+            if( device.psz_string ) free( device.psz_string );
+            return TRUE; /* Keep enumerating */
+        }
+
         msg_Dbg( p_vout, "selecting %s, %s", psz_desc, psz_drivername );
         p_vout->p_sys->p_display_driver = malloc( sizeof(GUID) );
         if( p_vout->p_sys->p_display_driver )
@@ -691,12 +754,21 @@ static int DirectXInitDDraw( vout_thread_t *p_vout )
 
     if( OurDirectDrawEnumerateEx && p_vout->p_sys->MonitorFromWindow )
     {
+        vlc_value_t device;
+
+        var_Get( p_vout, "directx-device", &device );
+        if( device.psz_string )
+        {
+            msg_Dbg( p_vout, "directx-device: %s", device.psz_string );
+            free( device.psz_string );
+        }
+
         p_vout->p_sys->hmonitor =
             p_vout->p_sys->MonitorFromWindow( p_vout->p_sys->hwnd,
                                               MONITOR_DEFAULTTONEAREST );
 
         /* Enumerate displays */
-        OurDirectDrawEnumerateEx( DirectXEnumCallback, p_vout, 
+        OurDirectDrawEnumerateEx( DirectXEnumCallback, p_vout,
                                   DDENUM_ATTACHEDSECONDARYDEVICES );
     }
 
@@ -1554,7 +1626,7 @@ static void DirectXGetDDrawCaps( vout_thread_t *p_vout )
                          bHasColorKey, bCanStretch, bCanBltFourcc );
 
         /* Don't ask for troubles */
-        if( !bCanBltFourcc ) p_vout->p_sys->b_hw_yuv = FALSE; 
+        if( !bCanBltFourcc ) p_vout->p_sys->b_hw_yuv = FALSE;
     }
 }
 
@@ -1618,7 +1690,7 @@ static int DirectXLockSurface( vout_thread_t *p_vout, picture_t *p_pic )
         return VLC_EGENERIC;
     }
     else
-        return VLC_SUCCESS;      
+        return VLC_SUCCESS;
 }
 
 /*****************************************************************************
@@ -1698,3 +1770,75 @@ static int OnTopCallback( vlc_object_t *p_this, char const *psz_cmd,
     p_vout->p_sys->b_on_top_change = VLC_TRUE;
     return VLC_SUCCESS;
 }
+
+/*****************************************************************************
+ * config variable callback
+ *****************************************************************************/
+BOOL WINAPI DirectXEnumCallback2( GUID* p_guid, LPTSTR psz_desc,
+                                  LPTSTR psz_drivername, VOID* p_context,
+                                  HMONITOR hmon )
+{
+    module_config_t *p_item = (module_config_t *)p_context;
+
+    p_item->ppsz_list =
+        (char **)realloc( p_item->ppsz_list,
+                          (p_item->i_list+2) * sizeof(char *) );
+    p_item->ppsz_list_text =
+        (char **)realloc( p_item->ppsz_list_text,
+                          (p_item->i_list+2) * sizeof(char *) );
+
+    p_item->ppsz_list[p_item->i_list] = strdup( psz_drivername );
+    p_item->ppsz_list_text[p_item->i_list] = NULL;
+    p_item->i_list++;
+    p_item->ppsz_list[p_item->i_list] = NULL;
+    p_item->ppsz_list_text[p_item->i_list] = NULL;
+
+    return TRUE; /* Keep enumerating */
+}
+
+static int FindDevicesCallback( vlc_object_t *p_this, char const *psz_name,
+                               vlc_value_t newval, vlc_value_t oldval, void *d)
+{
+    HRESULT (WINAPI *OurDirectDrawEnumerateEx)( LPDDENUMCALLBACKEXA, LPVOID,
+                                                DWORD );
+    HINSTANCE hddraw_dll;
+
+    module_config_t *p_item;
+    int i;
+
+    p_item = config_FindConfig( p_this, psz_name );
+    if( !p_item ) return VLC_SUCCESS;
+
+    /* Clear-up the current list */
+    if( p_item->i_list )
+    {
+        /* Keep the first entry */
+        for( i = 1; i < p_item->i_list; i++ )
+        {
+            free( p_item->ppsz_list[i] );
+            free( p_item->ppsz_list_text[i] );
+        }
+        /* TODO: Remove when no more needed */
+        p_item->ppsz_list[i] = NULL;
+        p_item->ppsz_list_text[i] = NULL;
+    }
+    p_item->i_list = 1;
+
+    /* Load direct draw DLL */
+    hddraw_dll = LoadLibrary("DDRAW.DLL");
+    if( hddraw_dll == NULL ) return VLC_SUCCESS;
+
+    OurDirectDrawEnumerateEx =
+      (void *)GetProcAddress( hddraw_dll, "DirectDrawEnumerateExA" );
+
+    if( OurDirectDrawEnumerateEx )
+    {
+        /* Enumerate displays */
+        OurDirectDrawEnumerateEx( DirectXEnumCallback2, p_item,
+                                  DDENUM_ATTACHEDSECONDARYDEVICES );
+    }
+
+    FreeLibrary( hddraw_dll );
+
+    return VLC_SUCCESS;
+}
