@@ -1,8 +1,8 @@
 /*****************************************************************************
  * vout.h: Windows DirectX video output header file
  *****************************************************************************
- * Copyright (C) 1998, 1999, 2000 VideoLAN
- * $Id: vout.h,v 1.5 2003/05/21 13:27:25 gbazin Exp $
+ * Copyright (C) 2001-2004 VideoLAN
+ * $Id: vout.h,v 1.12 2004/01/02 22:17:57 gbazin Exp $
  *
  * Authors: Gildas Bazin <gbazin@netcourrier.com>
  *
@@ -45,12 +45,18 @@ struct vout_sys_t
     LPDIRECTDRAWSURFACE2 p_current_surface;   /* surface currently displayed */
     LPDIRECTDRAWCLIPPER  p_clipper;             /* clipper used for blitting */
     HINSTANCE            hddraw_dll;       /* handle of the opened ddraw dll */
-    HBRUSH               hbrush;           /* window backgound brush (color) */
 
     HWND                 hwnd;                  /* Handle of the main window */
+    HWND                 hvideownd;        /* Handle of the video sub-window */
     HWND                 hparent;             /* Handle of the parent window */
     WNDPROC              pf_wndproc;             /* Window handling callback */
 
+    /* Multi-monitor support */
+    HMONITOR             hmonitor;          /* handle of the current monitor */
+    GUID                 *p_display_driver;
+    HMONITOR             (WINAPI* MonitorFromWindow)( HWND, DWORD );
+    BOOL                 (WINAPI* GetMonitorInfo)( HMONITOR, LPMONITORINFO );
+
     vlc_bool_t   b_using_overlay;         /* Are we using an overlay surface */
     vlc_bool_t   b_use_sysmem;   /* Should we use system memory for surfaces */
     vlc_bool_t   b_hw_yuv;    /* Should we use hardware YUV->RGB conversions */
@@ -77,8 +83,8 @@ struct vout_sys_t
 
     int          i_rgb_colorkey;      /* colorkey in RGB used by the overlay */
     int          i_colorkey;                 /* colorkey used by the overlay */
- 
-    volatile u16 i_changes;             /* changes made to the video display */
+
+    volatile uint16_t i_changes;        /* changes made to the video display */
 
     /* Mouse */
     volatile vlc_bool_t b_cursor_hidden;
@@ -106,7 +112,7 @@ struct picture_sys_t
 /*****************************************************************************
  * Prototypes from vout.c
  *****************************************************************************/
-void DirectXUpdateOverlay( vout_thread_t *p_vout );
+int DirectXUpdateOverlay( vout_thread_t *p_vout );
 
 /*****************************************************************************
  * Prototypes from events.c
@@ -118,4 +124,8 @@ void DirectXUpdateRects ( vout_thread_t *p_vout, vlc_bool_t b_force );
  * Constants
  *****************************************************************************/
 #define WM_VLC_HIDE_MOUSE WM_APP
+#define WM_VLC_CREATE_VIDEO_WIN WM_APP + 1
+#define WM_VLC_DESTROY_VIDEO_WIN WM_APP + 2
+#define WM_VLC_CHANGE_TEXT WM_APP + 3
 #define IDM_TOGGLE_ON_TOP WM_USER + 1
+#define DX_POSITION_CHANGE 0x1000
