@@ -1,8 +1,8 @@
 /*****************************************************************************
  * variables.c: routines for object variables handling
  *****************************************************************************
- * Copyright (C) 2002 VideoLAN
- * $Id: variables.c,v 1.21 2003/03/11 23:56:54 gbazin Exp $
+ * Copyright (C) 2002-2004 VideoLAN
+ * $Id: variables.c,v 1.38 2004/02/29 13:08:56 gbazin Exp $
  *
  * Authors: Samuel Hocevar <sam@zoy.org>
  *
@@ -44,6 +44,10 @@ struct callback_entry_t
  *****************************************************************************/
 static int CmpBool( vlc_value_t v, vlc_value_t w ) { return v.b_bool ? w.b_bool ? 0 : 1 : w.b_bool ? -1 : 0; }
 static int CmpInt( vlc_value_t v, vlc_value_t w ) { return v.i_int == w.i_int ? 0 : v.i_int > w.i_int ? 1 : -1; }
+static int CmpTime( vlc_value_t v, vlc_value_t w )
+{
+    return v.i_time == w.i_time ? 0 : v.i_time > w.i_time ? 1 : -1;
+}
 static int CmpString( vlc_value_t v, vlc_value_t w ) { return strcmp( v.psz_string, w.psz_string ); }
 static int CmpFloat( vlc_value_t v, vlc_value_t w ) { return v.f_float == w.f_float ? 0 : v.f_float > w.f_float ? 1 : -1; }
 static int CmpAddress( vlc_value_t v, vlc_value_t w ) { return v.p_address == w.p_address ? 0 : v.p_address > w.p_address ? 1 : -1; }
@@ -54,10 +58,65 @@ static int CmpAddress( vlc_value_t v, vlc_value_t w ) { return v.p_address == w.
 static void DupDummy( vlc_value_t *p_val ) { (void)p_val; /* unused */ }
 static void DupString( vlc_value_t *p_val ) { p_val->psz_string = strdup( p_val->psz_string ); }
 
+static void DupList( vlc_value_t *p_val )
+{
+    int i;
+    vlc_list_t *p_list = malloc( sizeof(vlc_list_t) );
+
+    if( p_val->p_list->i_count )
+    {
+        p_list->i_count = p_val->p_list->i_count;
+        p_list->p_values = malloc( p_list->i_count * sizeof(vlc_value_t) );
+        p_list->pi_types = malloc( p_list->i_count * sizeof(int) );
+    }
+
+    for( i = 0; i < p_list->i_count; i++ )
+    {
+        p_list->p_values[i] = p_val->p_list->p_values[i];
+        switch( p_val->p_list->pi_types[i] & VLC_VAR_TYPE )
+        {
+        case VLC_VAR_STRING:
+
+            DupString( &p_list->p_values[i] );
+            break;
+        default:
+            break;
+        }
+    }
+
+    p_val->p_list = p_list;
+}
+
 static void FreeDummy( vlc_value_t *p_val ) { (void)p_val; /* unused */ }
 static void FreeString( vlc_value_t *p_val ) { free( p_val->psz_string ); }
 static void FreeMutex( vlc_value_t *p_val ) { vlc_mutex_destroy( (vlc_mutex_t*)p_val->p_address ); free( p_val->p_address ); }
 
+static void FreeList( vlc_value_t *p_val )
+{
+    int i;
+    for( i = 0; i < p_val->p_list->i_count; i++ )
+    {
+        switch( p_val->p_list->pi_types[i] & VLC_VAR_TYPE )
+        {
+        case VLC_VAR_STRING:
+            FreeString( &p_val->p_list->p_values[i] );
+            break;
+        case VLC_VAR_MUTEX:
+            FreeMutex( &p_val->p_list->p_values[i] );
+            break;
+        default:
+            break;
+        }
+    }
+
+    if( p_val->p_list->i_count )
+    {
+        free( p_val->p_list->p_values );
+        free( p_val->p_list->pi_types );
+    }
+    free( p_val->p_list );
+}
+
 /*****************************************************************************
  * Local prototypes
  *****************************************************************************/
@@ -70,17 +129,26 @@ static int      LookupInner ( variable_t *, int, uint32_t );
 
 static void     CheckValue  ( variable_t *, vlc_value_t * );
 
-/*****************************************************************************
- * var_Create: initialize a vlc variable
- *****************************************************************************
+static int      InheritValue( vlc_object_t *, const char *, vlc_value_t *,
+                              int );
+
+/**
+ * Initialize a vlc variable
+ *
  * We hash the given string and insert it into the sorted list. The insertion
  * may require slow memory copies, but think about what we gain in the log(n)
  * lookup phase when setting/getting the variable value!
- *****************************************************************************/
+ *
+ * \param p_this The object in which to create the variable
+ * \param psz_name The name of the variable
+ * \param i_type The variables type. Must be one of \ref var_type combined with
+ *               zero or more \ref var_flags
+ */
 int __var_Create( vlc_object_t *p_this, const char *psz_name, int i_type )
 {
     int i_new;
     variable_t *p_var;
+    static vlc_list_t dummy_null_list = {0, NULL, NULL};
 
     vlc_mutex_lock( &p_this->var_lock );
 
@@ -93,7 +161,7 @@ int __var_Create( vlc_object_t *p_this, const char *psz_name, int i_type )
     if( i_new >= 0 )
     {
         /* If the types differ, variable creation failed. */
-        if( i_type != p_this->p_vars[i_new].i_type )
+        if( (i_type & ~VLC_VAR_DOINHERIT) != p_this->p_vars[i_new].i_type )
         {
             vlc_mutex_unlock( &p_this->var_lock );
             return VLC_EBADVAR;
@@ -122,8 +190,9 @@ int __var_Create( vlc_object_t *p_this, const char *psz_name, int i_type )
 
     p_var->i_hash = HashString( psz_name );
     p_var->psz_name = strdup( psz_name );
+    p_var->psz_text = NULL;
 
-    p_var->i_type = i_type;
+    p_var->i_type = i_type & ~VLC_VAR_DOINHERIT;
     memset( &p_var->val, 0, sizeof(vlc_value_t) );
 
     p_var->pf_dup = DupDummy;
@@ -134,6 +203,8 @@ int __var_Create( vlc_object_t *p_this, const char *psz_name, int i_type )
     p_var->i_default = -1;
     p_var->choices.i_count = 0;
     p_var->choices.p_values = NULL;
+    p_var->choices_text.i_count = 0;
+    p_var->choices_text.p_values = NULL;
 
     p_var->b_incallback = VLC_FALSE;
     p_var->i_entries = 0;
@@ -149,6 +220,7 @@ int __var_Create( vlc_object_t *p_this, const char *psz_name, int i_type )
             p_var->val.b_bool = VLC_FALSE;
             break;
         case VLC_VAR_INTEGER:
+        case VLC_VAR_HOTKEY:
             p_var->pf_cmp = CmpInt;
             p_var->val.i_int = 0;
             break;
@@ -167,7 +239,8 @@ int __var_Create( vlc_object_t *p_this, const char *psz_name, int i_type )
             p_var->val.f_float = 0.0;
             break;
         case VLC_VAR_TIME:
-            /* FIXME: TODO */
+            p_var->pf_cmp = CmpTime;
+            p_var->val.i_time = 0;
             break;
         case VLC_VAR_ADDRESS:
             p_var->pf_cmp = CmpAddress;
@@ -179,22 +252,58 @@ int __var_Create( vlc_object_t *p_this, const char *psz_name, int i_type )
             p_var->val.p_address = malloc( sizeof(vlc_mutex_t) );
             vlc_mutex_init( p_this, (vlc_mutex_t*)p_var->val.p_address );
             break;
+        case VLC_VAR_LIST:
+            p_var->pf_cmp = CmpAddress;
+            p_var->pf_dup = DupList;
+            p_var->pf_free = FreeList;
+            p_var->val.p_list = &dummy_null_list;
+            break;
     }
 
     /* Duplicate the default data we stored. */
     p_var->pf_dup( &p_var->val );
 
+    if( i_type & VLC_VAR_DOINHERIT )
+    {
+        vlc_value_t val;
+
+        if( InheritValue( p_this, psz_name, &val, p_var->i_type )
+            == VLC_SUCCESS );
+        {
+            /* Free data if needed */
+            p_var->pf_free( &p_var->val );
+            /* Set the variable */
+            p_var->val = val;
+
+            if( i_type & VLC_VAR_HASCHOICE )
+            {
+                /* We must add the inherited value to our choice list */
+                p_var->i_default = 0;
+
+                INSERT_ELEM( p_var->choices.p_values, p_var->choices.i_count,
+                             0, val );
+                INSERT_ELEM( p_var->choices_text.p_values,
+                             p_var->choices_text.i_count, 0, val );
+                p_var->pf_dup( &p_var->choices.p_values[0] );
+                p_var->choices_text.p_values[0].psz_string = NULL;
+            }
+        }
+    }
+
     vlc_mutex_unlock( &p_this->var_lock );
 
     return VLC_SUCCESS;
 }
 
-/*****************************************************************************
- * var_Destroy: destroy a vlc variable
- *****************************************************************************
+/**
+ * Destroy a vlc variable
+ *
  * Look for the variable and destroy it if it is found. As in var_Create we
  * do a call to memmove() but we have performance counterparts elsewhere.
- *****************************************************************************/
+ *
+ * \param p_this The object that holds the variable
+ * \param psz_name The name of the variable
+ */
 int __var_Destroy( vlc_object_t *p_this, const char *psz_name )
 {
     int i_var, i;
@@ -227,8 +336,11 @@ int __var_Destroy( vlc_object_t *p_this, const char *psz_name )
         for( i = 0 ; i < p_var->choices.i_count ; i++ )
         {
             p_var->pf_free( &p_var->choices.p_values[i] );
+            if( p_var->choices_text.p_values[i].psz_string )
+                free( p_var->choices_text.p_values[i].psz_string );
         }
         free( p_var->choices.p_values );
+        free( p_var->choices_text.p_values );
     }
 
     /* Free callbacks if needed */
@@ -238,6 +350,7 @@ int __var_Destroy( vlc_object_t *p_this, const char *psz_name )
     }
 
     free( p_var->psz_name );
+    if( p_var->psz_text ) free( p_var->psz_text );
 
     memmove( p_this->p_vars + i_var,
              p_this->p_vars + i_var + 1,
@@ -256,13 +369,17 @@ int __var_Destroy( vlc_object_t *p_this, const char *psz_name )
     return VLC_SUCCESS;
 }
 
-/*****************************************************************************
- * var_Change: perform an action on a variable
- *****************************************************************************
+/**
+ * Perform an action on a variable
  *
- *****************************************************************************/
+ * \param p_this The object that holds the variable
+ * \param psz_name The name of the variable
+ * \param i_action The action to perform. Must be one of \ref var_action
+ * \param p_val First action parameter
+ * \param p_val2 Second action parameter
+ */
 int __var_Change( vlc_object_t *p_this, const char *psz_name,
-                  int i_action, vlc_value_t *p_val )
+                  int i_action, vlc_value_t *p_val, vlc_value_t *p_val2 )
 {
     int i_var, i;
     variable_t *p_var;
@@ -332,7 +449,12 @@ int __var_Change( vlc_object_t *p_this, const char *psz_name,
 
             INSERT_ELEM( p_var->choices.p_values, p_var->choices.i_count,
                          i, *p_val );
+            INSERT_ELEM( p_var->choices_text.p_values,
+                         p_var->choices_text.i_count, i, *p_val );
             p_var->pf_dup( &p_var->choices.p_values[i] );
+            p_var->choices_text.p_values[i].psz_string =
+                ( p_val2 && p_val2->psz_string ) ?
+                strdup( p_val2->psz_string ) : NULL;
 
             CheckValue( p_var, &p_var->val );
             break;
@@ -363,10 +485,17 @@ int __var_Change( vlc_object_t *p_this, const char *psz_name,
             }
 
             p_var->pf_free( &p_var->choices.p_values[i] );
+            if( p_var->choices_text.p_values[i].psz_string )
+                free( p_var->choices_text.p_values[i].psz_string );
             REMOVE_ELEM( p_var->choices.p_values, p_var->choices.i_count, i );
+            REMOVE_ELEM( p_var->choices_text.p_values,
+                         p_var->choices_text.i_count, i );
 
             CheckValue( p_var, &p_var->val );
             break;
+        case VLC_VAR_CHOICESCOUNT:
+            p_val->i_int = p_var->choices.i_count;
+            break;
         case VLC_VAR_CLEARCHOICES:
             for( i = 0 ; i < p_var->choices.i_count ; i++ )
             {
@@ -410,26 +539,127 @@ int __var_Change( vlc_object_t *p_this, const char *psz_name,
             /* Free data if needed */
             p_var->pf_free( &oldval );
             break;
+        case VLC_VAR_GETCHOICES:
         case VLC_VAR_GETLIST:
             p_val->p_list = malloc( sizeof(vlc_list_t) );
+            if( p_val2 ) p_val2->p_list = malloc( sizeof(vlc_list_t) );
             if( p_var->choices.i_count )
+            {
                 p_val->p_list->p_values = malloc( p_var->choices.i_count
                                                   * sizeof(vlc_value_t) );
+                p_val->p_list->pi_types = malloc( p_var->choices.i_count
+                                                  * sizeof(int) );
+                if( p_val2 )
+                {
+                    p_val2->p_list->p_values =
+                        malloc( p_var->choices.i_count * sizeof(vlc_value_t) );
+                    p_val2->p_list->pi_types =
+                        malloc( p_var->choices.i_count * sizeof(int) );
+                }
+            }
             p_val->p_list->i_count = p_var->choices.i_count;
+            if( p_val2 ) p_val2->p_list->i_count = p_var->choices.i_count;
             for( i = 0 ; i < p_var->choices.i_count ; i++ )
             {
                 p_val->p_list->p_values[i] = p_var->choices.p_values[i];
+                p_val->p_list->pi_types[i] = p_var->i_type;
                 p_var->pf_dup( &p_val->p_list->p_values[i] );
+                if( p_val2 )
+                {
+                    p_val2->p_list->p_values[i].psz_string =
+                        p_var->choices_text.p_values[i].psz_string ?
+                    strdup(p_var->choices_text.p_values[i].psz_string) : NULL;
+                    p_val2->p_list->pi_types[i] = VLC_VAR_STRING;
+                }
             }
             break;
         case VLC_VAR_FREELIST:
-            for( i = p_val->p_list->i_count ; i-- ; )
+            FreeList( p_val );
+            if( p_val2 && p_val2->p_list )
             {
-                p_var->pf_free( &p_val->p_list->p_values[i] );
+                for( i = 0; i < p_val2->p_list->i_count; i++ )
+                    if( p_val2->p_list->p_values[i].psz_string )
+                        free( p_val2->p_list->p_values[i].psz_string );
+                if( p_val2->p_list->i_count )
+                {
+                    free( p_val2->p_list->p_values );
+                    free( p_val2->p_list->pi_types );
+                }
+                free( p_val2->p_list );
+            }
+            break;
+        case VLC_VAR_SETTEXT:
+            if( p_var->psz_text ) free( p_var->psz_text );
+            if( p_val && p_val->psz_string )
+                p_var->psz_text = strdup( p_val->psz_string );
+            break;
+        case VLC_VAR_GETTEXT:
+            p_val->psz_string = NULL;
+            if( p_var->psz_text )
+            {
+                p_val->psz_string = strdup( p_var->psz_text );
+            }
+            break;
+        case VLC_VAR_INHERITVALUE:
+            {
+                vlc_value_t val;
+
+                if( InheritValue( p_this, psz_name, &val, p_var->i_type )
+                    == VLC_SUCCESS );
+                {
+                    /* Duplicate already done */
+
+                    /* Backup needed stuff */
+                    oldval = p_var->val;
+                    /* Check boundaries and list */
+                    CheckValue( p_var, &val );
+                    /* Set the variable */
+                    p_var->val = val;
+                    /* Free data if needed */
+                    p_var->pf_free( &oldval );
+                }
+
+                if( p_val )
+                {
+                    *p_val = p_var->val;
+                    p_var->pf_dup( p_val );
+                }
+            }
+            break;
+        case VLC_VAR_TRIGGER_CALLBACKS:
+            {
+                /* Deal with callbacks. Tell we're in a callback, release the lock,
+                 * call stored functions, retake the lock. */
+                if( p_var->i_entries )
+                {
+                    int i_var;
+                    int i_entries = p_var->i_entries;
+                    callback_entry_t *p_entries = p_var->p_entries;
+
+                    p_var->b_incallback = VLC_TRUE;
+                    vlc_mutex_unlock( &p_this->var_lock );
+
+                    /* The real calls */
+                    for( ; i_entries-- ; )
+                    {
+                        p_entries[i_entries].pf_callback( p_this, psz_name, p_var->val, p_var->val,
+                                                          p_entries[i_entries].p_data );
+                    }
+
+                    vlc_mutex_lock( &p_this->var_lock );
+
+                    i_var = Lookup( p_this->p_vars, p_this->i_vars, psz_name );
+                    if( i_var < 0 )
+                    {
+                        msg_Err( p_this, "variable %s has disappeared", psz_name );
+                        vlc_mutex_unlock( &p_this->var_lock );
+                        return VLC_ENOVAR;
+                    }
+
+                    p_var = &p_this->p_vars[i_var];
+                    p_var->b_incallback = VLC_FALSE;
+                }
             }
-            if( p_val->p_list->i_count )
-                free( p_val->p_list->p_values );
-            free( p_val->p_list );
             break;
 
         default:
@@ -441,12 +671,13 @@ int __var_Change( vlc_object_t *p_this, const char *psz_name,
     return VLC_SUCCESS;
 }
 
-/*****************************************************************************
- * var_Type: request a variable's type
- *****************************************************************************
- * This function returns the variable type if it exists, or 0 if the
+/**
+ * Request a variable's type
+ *
+ * \return The variable type if it exists, or 0 if the
  * variable could not be found.
- *****************************************************************************/
+ * \see \ref var_type
+ */
 int __var_Type( vlc_object_t *p_this, const char *psz_name )
 {
     int i_var, i_type;
@@ -468,11 +699,13 @@ int __var_Type( vlc_object_t *p_this, const char *psz_name )
     return i_type;
 }
 
-/*****************************************************************************
- * var_Set: set a variable's value
- *****************************************************************************
+/**
+ * Set a variable's value
  *
- *****************************************************************************/
+ * \param p_this The object that hold the variable
+ * \param psz_name The name of the variable
+ * \param val the value to set
+ */
 int __var_Set( vlc_object_t *p_this, const char *psz_name, vlc_value_t val )
 {
     int i_var;
@@ -542,11 +775,14 @@ int __var_Set( vlc_object_t *p_this, const char *psz_name, vlc_value_t val )
     return VLC_SUCCESS;
 }
 
-/*****************************************************************************
- * var_Get: get a variable's value
- *****************************************************************************
+/**
+ * Get a variable's value
  *
- *****************************************************************************/
+ * \param p_this The object that holds the variable
+ * \param psz_name The name of the variable
+ * \param p_val Pointer to a vlc_value_t that will hold the variable's value
+ *              after the function is finished
+ */
 int __var_Get( vlc_object_t *p_this, const char *psz_name, vlc_value_t *p_val )
 {
     int i_var;
@@ -575,13 +811,22 @@ int __var_Get( vlc_object_t *p_this, const char *psz_name, vlc_value_t *p_val )
     return VLC_SUCCESS;
 }
 
-/*****************************************************************************
- * var_AddCallback: register a callback in a variable
- *****************************************************************************
- * We store a function pointer pf_callback that will be called upon variable
- * modification. p_data is a generic pointer that will be passed as additional
- * argument to the callback function.
- *****************************************************************************/
+/**
+ * Register a callback in a variable
+ *
+ * We store a function pointer that will be called upon variable
+ * modification.
+ *
+ * \param p_this The object that holds the variable
+ * \param psz_name The name of the variable
+ * \param pf_callback The function pointer
+ * \param p_data A generic pointer that will be passed as the last
+ *               argument to the callback function.
+ *
+ * \warning The callback function is run in the thread that calls var_Set on
+ *          the variable. Use proper locking. This thread may not have much
+ *          time to spare, so keep callback functions short.
+ */
 int __var_AddCallback( vlc_object_t *p_this, const char *psz_name,
                        vlc_callback_t pf_callback, void *p_data )
 {
@@ -613,12 +858,12 @@ int __var_AddCallback( vlc_object_t *p_this, const char *psz_name,
     return VLC_SUCCESS;
 }
 
-/*****************************************************************************
- * var_DelCallback: remove a callback from a variable
- *****************************************************************************
+/**
+ * Remove a callback from a variable
+ *
  * pf_callback and p_data have to be given again, because different objects
  * might have registered the same callback function.
- *****************************************************************************/
+ */
 int __var_DelCallback( vlc_object_t *p_this, const char *psz_name,
                        vlc_callback_t pf_callback, void *p_data )
 {
@@ -937,3 +1182,73 @@ static void CheckValue ( variable_t *p_var, vlc_value_t *p_val )
             break;
     }
 }
+
+/*****************************************************************************
+ * InheritValue: try to inherit the value of this variable from the same one
+ *               in our closest parent.
+ *****************************************************************************/
+static int InheritValue( vlc_object_t *p_this, const char *psz_name,
+                         vlc_value_t *p_val, int i_type )
+{
+    int i_var;
+    variable_t *p_var;
+
+    /* No need to take the structure lock,
+     * we are only looking for our parents */
+
+    if( !p_this->p_parent )
+    {
+        switch( i_type & VLC_VAR_TYPE )
+        {
+        case VLC_VAR_FILE:
+        case VLC_VAR_DIRECTORY:
+        case VLC_VAR_STRING:
+        case VLC_VAR_MODULE:
+            p_val->psz_string = config_GetPsz( p_this, psz_name );
+            if( !p_val->psz_string ) p_val->psz_string = strdup("");
+            break;
+        case VLC_VAR_FLOAT:
+            p_val->f_float = config_GetFloat( p_this, psz_name );
+            break;
+        case VLC_VAR_INTEGER:
+        case VLC_VAR_HOTKEY:
+            p_val->i_int = config_GetInt( p_this, psz_name );
+            break;
+        case VLC_VAR_BOOL:
+            p_val->b_bool = config_GetInt( p_this, psz_name );
+            break;
+        default:
+            return VLC_ENOOBJ;
+            break;
+        }
+
+        return VLC_SUCCESS;
+    }
+
+    /* Look for the variable */
+    vlc_mutex_lock( &p_this->p_parent->var_lock );
+
+    i_var = Lookup( p_this->p_parent->p_vars, p_this->p_parent->i_vars,
+                    psz_name );
+
+    if( i_var >= 0 )
+    {
+        /* We found it! */
+        p_var = &p_this->p_parent->p_vars[i_var];
+
+        /* Really get the variable */
+        *p_val = p_var->val;
+
+        /* Duplicate value if needed */
+        p_var->pf_dup( p_val );
+
+        vlc_mutex_unlock( &p_this->p_parent->var_lock );
+        return VLC_SUCCESS;
+    }
+
+    vlc_mutex_unlock( &p_this->p_parent->var_lock );
+
+    /* We're still not there */
+
+    return InheritValue( p_this->p_parent, psz_name, p_val, i_type );
+}
