@@ -1,8 +1,8 @@
 /*****************************************************************************
  * stream_output.c : stream output module
  *****************************************************************************
- * Copyright (C) 2002 VideoLAN
- * $Id: stream_output.c,v 1.36 2003/12/07 17:09:33 gbazin Exp $
+ * Copyright (C) 2002-2004 VideoLAN
+ * $Id: stream_output.c,v 1.40 2004/02/22 16:08:47 fenrir Exp $
  *
  * Authors: Christophe Massiot <massiot@via.ecp.fr>
  *          Laurent Aimar <fenrir@via.ecp.fr>
@@ -174,20 +174,11 @@ void sout_DeleteInstance( sout_instance_t * p_sout )
 /*****************************************************************************
  * Packetizer/Input
  *****************************************************************************/
-sout_packetizer_input_t *__sout_InputNew( vlc_object_t  *p_this,
-                                          es_format_t *p_fmt )
+sout_packetizer_input_t *sout_InputNew( sout_instance_t *p_sout,
+                                        es_format_t *p_fmt )
 {
-    sout_instance_t         *p_sout = NULL;
     sout_packetizer_input_t *p_input;
 
-    /* search an stream output */
-    if( !( p_sout = vlc_object_find( p_this, VLC_OBJECT_SOUT, FIND_ANYWHERE ) ) )
-    {
-        /* can't happen ... */
-        msg_Err( p_this, "cannot find any stream ouput" );
-        return NULL;
-    }
-
     msg_Dbg( p_sout, "adding a new input" );
 
     /* *** create a packetizer input *** */
@@ -203,16 +194,13 @@ sout_packetizer_input_t *__sout_InputNew( vlc_object_t  *p_this,
 
     /* *** add it to the stream chain */
     vlc_mutex_lock( &p_sout->lock );
-    p_input->id = p_sout->p_stream->pf_add( p_sout->p_stream,
-                                            p_fmt );
+    p_input->id = p_sout->p_stream->pf_add( p_sout->p_stream, p_fmt );
     vlc_mutex_unlock( &p_sout->lock );
 
-    vlc_object_release( p_sout );
-
     if( p_input->id == NULL )
     {
         free( p_input );
-        return( NULL );
+        return NULL;
     }
 
     return( p_input );
@@ -237,8 +225,8 @@ int sout_InputDelete( sout_packetizer_input_t *p_input )
     return( VLC_SUCCESS);
 }
 
-
-int sout_InputSendBuffer( sout_packetizer_input_t *p_input, sout_buffer_t *p_buffer )
+int sout_InputSendBuffer( sout_packetizer_input_t *p_input,
+                          sout_buffer_t *p_buffer )
 {
     sout_instance_t     *p_sout = p_input->p_sout;
     int                 i_ret;
@@ -249,8 +237,16 @@ int sout_InputSendBuffer( sout_packetizer_input_t *p_input, sout_buffer_t *p_buf
         return VLC_SUCCESS;
     }
 
+    if( !p_buffer->i_dts )
+    {
+        msg_Warn( p_sout, "trying to send non-dated packet to stream output!");
+        sout_BufferDelete( p_input->p_sout, p_buffer );
+        return VLC_SUCCESS;
+    }
+
     vlc_mutex_lock( &p_sout->lock );
-    i_ret = p_sout->p_stream->pf_send( p_sout->p_stream, p_input->id, p_buffer );
+    i_ret = p_sout->p_stream->pf_send( p_sout->p_stream,
+                                       p_input->id, p_buffer );
     vlc_mutex_unlock( &p_sout->lock );
 
     return i_ret;
@@ -272,7 +268,8 @@ sout_access_out_t *sout_AccessOutNew( sout_instance_t *p_sout,
         return NULL;
     }
 
-    psz_next = sout_cfg_parser( &p_access->psz_access, &p_access->p_cfg, psz_access );
+    psz_next = sout_cfg_parser( &p_access->psz_access, &p_access->p_cfg,
+                                psz_access );
     if( psz_next )
     {
         free( psz_next );
@@ -281,6 +278,7 @@ sout_access_out_t *sout_AccessOutNew( sout_instance_t *p_sout,
     p_access->p_sout     = p_sout;
     p_access->p_sys = NULL;
     p_access->pf_seek    = NULL;
+    p_access->pf_read    = NULL;
     p_access->pf_write   = NULL;
 
     p_access->p_module   =
@@ -317,20 +315,28 @@ void sout_AccessOutDelete( sout_access_out_t *p_access )
 /*****************************************************************************
  * sout_AccessSeek:
  *****************************************************************************/
-int  sout_AccessOutSeek( sout_access_out_t *p_access, off_t i_pos )
+int sout_AccessOutSeek( sout_access_out_t *p_access, off_t i_pos )
 {
-    return( p_access->pf_seek( p_access, i_pos ) );
+    return p_access->pf_seek( p_access, i_pos );
+}
+
+/*****************************************************************************
+ * sout_AccessRead:
+ *****************************************************************************/
+int sout_AccessOutRead( sout_access_out_t *p_access, sout_buffer_t *p_buffer )
+{
+    return ( p_access->pf_read ?
+             p_access->pf_read( p_access, p_buffer ) : VLC_EGENERIC );
 }
 
 /*****************************************************************************
  * sout_AccessWrite:
  *****************************************************************************/
-int  sout_AccessOutWrite( sout_access_out_t *p_access, sout_buffer_t *p_buffer )
+int sout_AccessOutWrite( sout_access_out_t *p_access, sout_buffer_t *p_buffer )
 {
-    return( p_access->pf_write( p_access, p_buffer ) );
+    return p_access->pf_write( p_access, p_buffer );
 }
 
-
 /*****************************************************************************
  * MuxNew: allocate a new mux
  *****************************************************************************/
