@@ -1,8 +1,8 @@
 /*****************************************************************************
  * vout_pictures.c : picture management functions
  *****************************************************************************
- * Copyright (C) 2000 VideoLAN
- * $Id: vout_pictures.c,v 1.43 2003/10/24 21:27:07 gbazin Exp $
+ * Copyright (C) 2000-2004 VideoLAN
+ * $Id: vout_pictures.c,v 1.47 2004/02/27 14:01:35 fenrir Exp $
  *
  * Authors: Vincent Seguin <seguin@via.ecp.fr>
  *          Samuel Hocevar <sam@zoy.org>
@@ -165,7 +165,8 @@ picture_t *vout_CreatePicture( vout_thread_t *p_vout,
      */
     if( p_freepic != NULL )
     {
-        vout_AllocatePicture( p_vout, p_freepic, p_vout->render.i_chroma,
+        vout_AllocatePicture( VLC_OBJECT(p_vout),
+                              p_freepic, p_vout->render.i_chroma,
                               p_vout->render.i_width, p_vout->render.i_height,
                               p_vout->render.i_aspect );
 
@@ -260,7 +261,7 @@ void vout_UnlinkPicture( vout_thread_t *p_vout, picture_t *p_pic )
 
     if( p_pic->i_refcount < 0 )
     {
-        msg_Err( p_vout, "picture %p refcount is %i", 
+        msg_Err( p_vout, "picture %p refcount is %i",
                  p_pic, p_pic->i_refcount );
         p_pic->i_refcount = 0;
     }
@@ -455,13 +456,13 @@ void vout_PlacePicture( vout_thread_t *p_vout,
  * used exactly like a video buffer. The video output thread then manages
  * how it gets displayed.
  *****************************************************************************/
-void vout_AllocatePicture( vout_thread_t *p_vout, picture_t *p_pic,
+void vout_AllocatePicture( vlc_object_t *p_this, picture_t *p_pic,
                            vlc_fourcc_t i_chroma,
                            int i_width, int i_height, int i_aspect )
 {
     int i_bytes, i_index;
 
-    vout_InitPicture( VLC_OBJECT(p_vout), p_pic, i_chroma,
+    vout_InitPicture( p_this, p_pic, i_chroma,
                       i_width, i_height, i_aspect );
 
     /* Calculate how big the new image should be */
@@ -527,6 +528,7 @@ void vout_InitFormat( video_frame_format_t *p_format, vlc_fourcc_t i_chroma,
             p_format->i_bits_per_pixel = 12;
             break;
         case FOURCC_I410:
+        case FOURCC_YVU9:
             p_format->i_bits_per_pixel = 9;
             break;
         case FOURCC_Y211:
@@ -595,6 +597,7 @@ void vout_InitPicture( vlc_object_t *p_this, picture_t *p_pic,
             break;
 
         case FOURCC_I410:
+        case FOURCC_YVU9:
             p_pic->p[ Y_PLANE ].i_lines = i_height;
             p_pic->p[ Y_PLANE ].i_pitch = i_width;
             p_pic->p[ Y_PLANE ].i_visible_pitch = p_pic->p[ Y_PLANE ].i_pitch;
